#
# spec file for package gnumeric
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gnumeric
Version:        1.12.41
Release:        lp152.3.8
Summary:        Spreadsheet Application
License:        GPL-2.0-only OR GPL-3.0-only
Group:          Productivity/Office/Spreadsheets
URL:            http://www.gnumeric.org/
Source0:        http://download.gnome.org/sources/gnumeric/1.12/%{name}-%{version}.tar.xz
Source1:        gnumeric-rpmlintrc
BuildRequires:  bison
BuildRequires:  docbook-dtds
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  itstool
BuildRequires:  libgsf-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  python-devel
BuildRequires:  translation-update-upstream
BuildRequires:  pkgconfig(gio-2.0) >= 2.38.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.38.0
BuildRequires:  pkgconfig(gmodule-2.0) >= 2.38.0
BuildRequires:  pkgconfig(gobject-2.0) >= 2.38.0
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 1.0.0
BuildRequires:  pkgconfig(gthread-2.0) >= 2.38.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.8.7
BuildRequires:  pkgconfig(libgda-5.0) >= 5.0.0
BuildRequires:  pkgconfig(libgda-ui-5.0) >= 5.0.0
BuildRequires:  pkgconfig(libgoffice-0.10) >= 0.10.40
BuildRequires:  pkgconfig(libgsf-1) >= 1.14.33
BuildRequires:  pkgconfig(libxml-2.0) >= 2.4.12
BuildRequires:  pkgconfig(pango) >= 1.24.0
BuildRequires:  pkgconfig(pangocairo) >= 1.24.0
BuildRequires:  pkgconfig(pygobject-3.0) >= 3.0.0
Recommends:     %{name}-doc
Recommends:     %{name}-lang
Recommends:     ghostscript-fonts-std
Recommends:     liberation-fonts
# gnumeric uses a ghelp: URI to launch the help application. Let's recommend to have an app that can handle it (bnc#719679)
Recommends:     mimehandler(x-scheme-handler/ghelp)
Provides:       gnumeric2 = %{version}
Obsoletes:      gnumeric2 < %{version}
%{perl_requires}
%{?libperl_requires}

%description
Gnumeric is a spreadsheet application with advanced features and
analytics.  It aims to minimize the cost of transition from proprietary
spreadsheets by offering a familiar look and feature set.  In addition
to read and write support for all versions of Microsoft Excel
(including reading encrypted files), there is also support for many
other formats including:

*Applix 4 and 5 *DIF *Lotus-123 (wk1, wk2, wk3) *OpenOffice.org (Oasis)
*PlanPerfect (pln) *Psion5 *Quattro Pro (wb1, wb2, wb3) *SYLK
*XBase/DB3

Text formats, such as comma or tab separated values, HTML, XHTML, and
Latex, are supported and there are powerful assistants to handle custom
needs.

Gnumeric is part of the GNOME project.

%package doc
Summary:        Documentation files for Gnumeric
Group:          Documentation/Other
Requires:       %{name} = %{version}
BuildArch:      noarch

%description doc
Gnumeric is a spreadsheet application with advanced features and
analytics.  It aims to minimize the cost of transition from proprietary
spreadsheets by offering a familiar look and feature set.  In addition
to read and write support for all versions of Microsoft Excel
(including reading encrypted files), there is also support for many
other formats including:

*Applix 4 and 5 *DIF *Lotus-123 (wk1, wk2, wk3) *OpenOffice.org (Oasis)
*PlanPerfect (pln) *Psion5 *Quattro Pro (wb1, wb2, wb3) *SYLK
*XBase/DB3

Text formats, such as comma or tab separated values, HTML, XHTML, and
Latex, are supported and there are powerful assistants to handle custom
needs.

Gnumeric is part of the GNOME project.

%package devel
Summary:        Spreadsheet Application
Group:          Development/Libraries/GNOME
Requires:       %{name} = %{version}

%description devel
Gnumeric is a spreadsheet application with advanced features and
analytics.  It aims to minimize the cost of transition from proprietary
spreadsheets by offering a familiar look and feature set.  In addition
to read and write support for all versions of Microsoft Excel
(including reading encrypted files), there is also support for many
other formats including:

*Applix 4 and 5 *DIF *Lotus-123 (wk1, wk2, wk3) *OpenOffice.org (Oasis)
*PlanPerfect (pln) *Psion5 *Quattro Pro (wb1, wb2, wb3) *SYLK
*XBase/DB3

Text formats, such as comma or tab separated values, HTML, XHTML, and
Latex, are supported and there are powerful assistants to handle custom
needs.

Gnumeric is part of the GNOME project.

%lang_package

%prep
%setup -q
translation-update-upstream
translation-update-upstream po-functions gnumeric-functions
# remove incomplete translations caused by translation-update-upstream (global LINGUAS file, two domains)
for LNG in po/*.po ; do
    LNG=`basename ${LNG%%.po}`
    if ! test -f po-functions/$LNG.po ; then
        echo "Removing incomplete $LNG from LINGUAS."
        sed -i "/^$LNG\$/d" po/LINGUAS
    fi
done

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
autoreconf -fiv
%configure\
	--disable-static
#	--enable-pdfdocs
make %{?_smp_mflags}

%install
%make_install
# FIXME: Build as root modifies system!
%find_lang %{name} %{?no_lang_C}
%find_lang %{name}-%{version} %{?no_lang_C} %{name}.lang
%find_lang %{name}-%{version}-functions %{?no_lang_C} %{name}.lang
find %{buildroot} -type f -name "*.la" -delete -print
%fdupes %{buildroot}%{_datadir}

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%license COPYING COPYING-gpl2 COPYING-gpl3
%doc AUTHORS BEVERAGES BUGS HACKING MAINTAINERS NEWS README ChangeLog
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%{name}.appdata.xml
%{_bindir}/*
%{_libdir}/*.so
%dir %{_libdir}/gnumeric
%dir %{_libdir}/gnumeric/*[^t]
%dir %{_libdir}/gnumeric/*/plugins
%dir %{_libdir}/gnumeric/*/plugins/*
%{_libdir}/gnumeric/*/plugins/*/*.so
%{_libdir}/gnumeric/*/plugins/*/*.xml
%{_libdir}/gnumeric/*/plugins/*/*.py
%{_libdir}/gnumeric/*/plugins/*/*.pl
%{_libdir}/gnumeric/*/plugins/gnome-glossary/glossary-po-header
%{_libdir}/goffice/*/plugins/gnumeric/
%{_datadir}/applications/gnumeric.desktop
%{_datadir}/glib-2.0/schemas/org.gnome.gnumeric.dialogs.gschema.xml
%{_datadir}/glib-2.0/schemas/org.gnome.gnumeric.gschema.xml
%{_datadir}/glib-2.0/schemas/org.gnome.gnumeric.plugin.gschema.xml
%{_datadir}/gnumeric/
%{_datadir}/icons/hicolor/*/apps/gnumeric.*
%{_datadir}/pixmaps/*.png
%{_datadir}/pixmaps/win32-gnumeric.ico
%{_datadir}/pixmaps/gnumeric/
%{_mandir}/man?/*%{ext_man}

%files doc
%doc %{_datadir}/help/C/%{name}

%files devel
%{_includedir}/libspreadsheet-*/
%{_libdir}/pkgconfig/libspreadsheet-*.pc

%files lang -f %{name}.lang

%changelog
* Tue May  8 2018 bjorn.lie@gmail.com
- Update to version 1.12.41:
  + Fix problem with object pasting.
  + Fix undo problem for cell comments (bgo#732653).
  + Exit with non-zero with we fail to load file on command line.
  + Fix undo crash (bgo#795861).
  + Introspection fixes.
  + Don't offer more than 15 significant digits by default
    (bgo#754391).
* Thu May  3 2018 bjorn.lie@gmail.com
- Update to version 1.12.40:
  + Fix histogram tool for the case of no labels (bgo#795475).
  + Introspection fixes.
  + Add floating-point environment sanity check (bgo#794515).
  + Before saving, verify that files hasn't changed on disk
    (bgo#334024).
  + Add GUI for comparing sheets.
  + Clean up workbook view construction.
  + Test suite improvements.
  + Fix problems with boxed types.
  + Avoid most punting for object properties.
  + Fix paste from LibreOffice.
  + Fix paste to LibreOffice -- use Biff8 (bgo#795280).
  + Allow inter-process paste-special (bgo#346630).
  + Fix ssconvert --merge-to problem with names (bgo#795408).
  + Fix problem with image pasting.
  + Allow pasting an image into Gnumeric (bgo#366816).
  + Full-column paste includes column width (bgo#121722).
  + Auto-fix shared array formulas in gnumeric files.
  + No-net-access doc build (bgo#790226).
  + No-net test suite fixes.
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Wed Mar 14 2018 luc14n0@linuxmail.org
- Update to version 1.12.39:
  + Fix ssdiff problem (bgo#792038).
  + Fix ISREF.
  + Fix problem with stopping a glpk solver.
  + Improve workaround for gtk+ scrollbar bug (bgo#792417).
  + Fix minor issue for MUNIT.
  + Documentation fixes (bgo#792556, bgo#792592).
- Drop update-desktop-files BuildRequires and suse_update_desktop_\
  file macro: they are no longer required.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Wed Jan 24 2018 pgajdos@suse.com
- Recommen liberation-fonts instead of liberation2-fonts,
  liberation2-fonts is dead (bsc#1077375, rh#856239).
* Fri Dec 29 2017 zaitor@opensuse.org
- Update to version 1.12.38:
  + Avoid large stack use here and there.
  + Test suite improvements.
  + Improve sylk writer.  Don't ask.
  + Teach ssdiff about column/row sizes.
  + Teach ssdiff about defined names.
  + Fix a few ssdiff crashes.
  + Fix crash on text import.
- Use plain make call again, fix build for old versions of
  openSUSE.
* Sat Dec  2 2017 luc14n0@linuxmail.org
- Update to version 1.12.37:
  + Improvements in:
  - Test suite.
  - Format guessing for newly entered formulas.
  - PERMUTATIONA for unusual arguments (bgo#790742).
  - xlsx export of cell comments (bgo#790756).
  + Fixes:
  - Combo object icon.
  - Potential crash:
    . On exit.
    . in gtk scroll bar bug workaround.
  + Speed-up number theory functions.
  + Avoid large stack use here and there.
  + Extend range of NT_PI.
  + Plug leaks.
- Point fdupes to the data directory instead of build root, which
  is a practice that must be avoided.
- Adopt the use of %%make_build macro instead of raw make command,
  following the best practices.
- Add gnumeric-rpmlintrc to filter the following warnings:
  + hidden-file-or-dir: some .category files are not meant to be
    edited.
  + shlib-policy-missing-suffix: spliting the package into a libfoo
    subpackage are not desired at the moment.
  + script-without-shebang: some python scripts under
    /usr/lib(64)/gnumeric/$version/plugins/foo/foo.py are not meant
    to be used in command line.
* Sun Nov 19 2017 luc14n0@linuxmail.org
- Update to version 1.12.36:
  + Improvements in:
  - Contour plot:
    . Export/import to/from ODF (bgo#788728).
    . Import of Excel generated ODF (bgo#788801).
  - Surface plot export to ODF (bgo#788447).
  + Fixes:
  - Export/import of CONCATENATE and minor axis divisors to and
    from ODF.
  - Import of affine trendline from ODF (bgo#789538).
  - Background of multiple selection (bgo#789411).
  - Error on xlsx files with bogus Print_Area.
  - xlsx:
    . Export of trend line equation.
    . Import and export of trend line affine flag.
  - VDB for partial periods (bgo#790299).
  + Workaround for gtk scroll bar bug (bgo#789412).
  + Convert all xpm files to png.
  + Avoid to-pixdata options for resources. It's going away.
  + Minor CORREL improvement.
  + xlsx import and export improvements for contour graphs.
  + Avoid critical on exporting unnamed xlsx trend line.
- Drop %%glib2_gsettings_schema_*, %%desktop_database_* and
  %%icon_theme_cache_* post/postun scriptlets: they are no longer
  needed since RPM file triggers.
- Drop --disable-scrollkeeper and --enable-ssindex configure
  parameters: no longer available.
- Add gio-2.0, gmodule-2.0, gobject-2.0 and gthread-2.0 pkgconfig
  BuildRequires: note that they already were being pulled with
  pkgconfig(glib-2.0) and used since they live in the same devel
  package.
- Change Group of devel package to Development/Libraries/GNOME
  since it's where the package belongs.
- Split package into a -doc subpackage: more than half the size of
  the package was documentation.
* Tue Jul 11 2017 zaitor@opensuse.org
- Update to version 1.12.35:
  + Fix cell border style selectors with recent gdk-pixbuf
    (bgo#781988).
  + Test suite improvements.
  + Improve relative accuracy of BESSELJ and BESSELY.
  + New function REDUCEPI.
  + Fix further fallout from glpk format change (bgo#783077).
* Tue Mar 21 2017 dimstar@opensuse.org
- Update to version 1.12.34:
  + Fix hyperlinks import from ODF (bgo#779635).
  + Fix xlsx export of chart series names (bgo#778618).
  + Always export a transparent fill style in charts (bgo#779160).
  + Doc fixes.
  + Fix xlsx import with missing header/footer (bgo#778292).
  + Minor xlsx import improvements with alias colors.
  + Test suite improvements.
  + Improve Excel handling of hyperlinks.
  + Hyperlinks improvements (bgo#706671).
  + Plug leaks.
  + Fix issues with sheet-local names.
  + ssdiff improvements with hyperlinks, input messages,
    conditional formats, and validations.
  + Make exit code from ssdiff follow diff's.
  + Fix ssdiff with inter-sheet references.
  + Fix style border colour sharing.
- Drop gnumeric-1.12.33-destdir.patch and
  gnumeric-1.12.33-docbook.patch: fixed upstream.
* Tue Jan 31 2017 firebird209@gmail.com
- Update to version 1.12.33:
  + Fix export/import of scaling information to/from ODF.
  + Fix Wilcoxon Signed Rank Test handling of ties (bgo#772718).
  + Fix xlsx export of scale to page information (bgo#776196).
  + Fix use of cell formats in graphs data labels (bgo#777338).
  + Speed up sstest part of test suite.
  + Bring documentation build into the 21 century.
  + Non-linear solver improvements.
  + Avoid atomizing style regions with conditional formats.
  + Adapt to glpk file format changes.
  + Fix stf problems with text format (bgo#777543).
- Updated Recommends: liberation-fonts to liberation2-fonts.
- Add gnumeric-1.12.33-destdir.patch: Fix compilation, destdir of
  helpfiles.
- Add docbook-dtds and itstool BuildRequires: New dependency after
  above patch.
- Following the above, drop rarian-scrollkeeper-compat
  BuildRequires: No longer needed.
- Add gnumeric-1.12.33-docbook.patch: Fixes some problems with
  non-ascii parameter names.
* Sat Aug 20 2016 zaitor@opensuse.org
- Update to version 1.12.32:
  + Improve html4.0 fragment export (bgo#769343).
  + Fix moving averages, exponential smothing and principal
    component tools (bgo#769659).
  + Fix paradox plugin build with pxlib-0.6.7 (bgo#769319).
  + Avoid gnome-common dependency.
  + New text functions CONCAT, TEXTJOIN.
  + New selection functions IFS, SWITCH.
  + New aggregation functions SUMIFS, AVERAGEIFS, MINIFS, MAXIFS,
    COUNTIFS.
  + Fix criteria function issue with errors in the selector area.
  + Fix corner case for MINA and MAXA.
  + Fix criteria matching of numbers against strings.
  + Test suite improvements.
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
- Remove obsolete clean section.
* Thu Jun 30 2016 zaitor@opensuse.org
- Update to version 1.12.31:
  + Fix case issues for database functions.
  + Anchor COUNTIF criteria at end too.
  + Add tests for COUNTIF.
  + Fix inter-process paste crash (bgo#768164).
* Sun Jun 19 2016 zaitor@opensuse.org
- Update to version 1.12.30:
  + Improve format guessing for csv and txt files.
  + Fix DCOUNT and DCOUNTA with missing field (bgo#767290).
  + Fix strictness in database functions.
  + Fix a bunch of corner cases for database functions.
  + Add tests for database functions.
* Sat May  7 2016 zaitor@opensuse.org
- Update to version 1.12.29:
  + Fix array reading in plots using matrix data (bgo#765483).
  + Documentation fixes for complex numbers.
  + Fix rare RANDBETWEEN problem.
  + Test suite improvements.
  + Fix value-area problem (bgo#765438).
  + Make xlsx shared strings parsing more robust (bgo#765544).
* Wed Mar 23 2016 dimstar@opensuse.org
- Update to version 1.12.28:
  + Fuzzed file fixes (bgo#761663, bgo#761727, bgo#762278).
  + Plug leaks.
  + Fix problems with ssconvert to lp/cplex formats.
  + Add sensitivity report to solver.
  + Fix bounds problem with cplex exporter.
  + Fix IMARCCOSH(1).
  + Add more tests for complex number evaluation.
  + Improve accuracy of IMLOG10.
* Sat Feb  6 2016 zaitor@opensuse.org
- Update to version 1.12.27:
  + Read/write rich-text font-size from ODF files (bgo#759983).
  + Read/write zoom values to/from ODF files in LO compatible way
    (bgo#700013).
  + Read new attribute to am/pm element in ODF import (bgo#760043).
  + Fix NETWORKDAYS (bgo#760576).
  + Fuzzed file fix (bgo#760546).
  + Fix data labels when the source is a range with several rows
    and columns (bgo#761048).
  + Teach ssconvert to split sheets into separate .txt files
    (bgo#694408).
  + Improve test suite.
  + Fuzzed file fixes: bgo#760046, bgo#760085, bgo##760087,
    bgo#760089, bgo#760043, bgo#760103, bgo#760102, bgo##760101,
    bgo#760105, bgo#760106, bgo#760104, bgo#760229, bgo#760231,
    bgo#760232, bgo#760544, bgo#760545, bgo#761295.
  + Fix R.DBINOM extreme-value case (bgo#760230).
  + New function AGM.
  + Fix canvas problem leaving grab in place (bgo#760639).
  + Work around gtk+ bug causing growing windows (bgo#761142).
  + Improve BESSELJ and BESSELY.
  + Improve BETA accuracy.
  + Fix problem with database functions (bgo#761305).
  + Fix font problem for ssconvert to pdf (bgo#761296).
  + Fix bison check (bgo#761398).
  + Improve IMIGAMMA coverage.
- Add bison BuildRequires: New dependency.
* Tue Dec 29 2015 dimstar@opensuse.org
- Update to version 1.12.26:
  + Fix potential crasher on showing initial window.
* Sat Dec 26 2015 damjanovic.ivo@gmail.com
- Update to version 1.12.25:
  + Add support in recent files dialog for multiple selesction
    and double click (bgo#759160).
  + Fix TABLE problems (bgo#752181, bgo#752178, bgo#752182).
  + Fuzzed file fixes (bgo#752179, bgo#752180).
  + Add R.DGUMBEL, R.PGUMBEL, R.QGUMBEL.
  + Fix conditional format problem (bgo#750271).
  + Test also RANDWEIBULL and RANDLOGNORM.
  + Fix problem with R.QHYPER.
  + Add R.DRAYLEIGH, R.PRAYLEIGH, R.QRAYLEIGH.
  + Fix GUI translation problems.
  + Fix bugs with merged cells (bgo#504004).
  + Make builds more reproducible.
  + Improve ssdiff for validation.
  + Fix problem with xls export of list validation (bgo#557555).
* Fri Nov 27 2015 zaitor@opensuse.org
- Update to version 1.12.24:
  + Fix printing of sheet objects with one cell or absolute anchors
    (bgo#753961).
  + Fix snap to grid for one cell or absolute anchored objects
    (bgo#754792).
  + On export, just change the extension, not more (lp#1497344).
* Mon Aug  3 2015 zaitor@opensuse.org
- Update to version 1.12.23:
  + Fix memory handling error on fuzzed sxc file (bgo#748535).
  + Improve import/export of page layout from/to ODF.
  + Improve function import to ODF (bgo#750627).
  + Add CONFIDENCE.T, MODE.MULT, PERCENTILE.EXC, PERCENTRANK.EXC
    and QUARTILE.EXC.
  + Fix ODF import of named expressions (bgo#750627).
  + Import reference unions from ODF (bgo#750627).
  + Improve CONVERT function.
  + Fix xlsx import of plot area manual layout (bgo#748016).
  + Fix out of bounds read (bgo#749121).
  + Fix import/export of graph backplane.
  + Fix export of unlabelled axes.
  + Fix export of rotated axis labels.
  + Fix xlsx save crash related to shared strings (bgo#748477).
  + Solver code refactoring.
  + Plug leaks.
  + Make solver check linearity of model.
  + Fix xls saving of marker style (bgo#749185).
  + Make compilation with clang work again (bgo#749138).
  + Fix xlsx problem with import of header/footer (bgo#750853).
  + Fix xls save problem with characters outside codepage
    (bgo#750856).
  + Fix named expression problem (bgo#751056).
  + Fix xlsx namespace problem (bgo#751120).
  + Protect database functions against malformed database
    (bgo#751392).
  + Fix csv problem with invalid UTF-8 data (bgo#751577).
  + Fix GROWTH (bgo#751658).
  + Restrict TABLE to array context (bgo#751871).
  + Fuzzed file fixes: bgo#750042, bgo#751217, bgo#751270,
    bgo#751060, bgo#751501, bgo#751851, bgo#751922, bgo#752124,
    bgo#751271, bgo#751383, bgo#751384, bgo#751758, bgo#751744,
    bgo#751908, bgo#751920, bgo#751249, bgo#751945, bgo#751909,
    bgo#751946, bgo#751968, bgo#751969, bgo#751971, bgo#751989,
    bgo#748595, bgo#748597, bgo#749031, bgo#749030, bgo#749069,
    bgo#748533, bgo#749118, bgo#749166, bgo#749181, bgo#749184,
    bgo#749236, bgo#749240, bgo#749234, bgo#749235, bgo#749271,
    bgo#749270, bgo#749424, bgo#749917, bgo#749919, bgo#750043,
    bgo#750044, bgo#750046, bgo#750811, bgo#750810, bgo#750857,
    bgo#750864, bgo#750862, bgo#750858, bgo#751126, bgo#751254,
    bgo#751253, bgo#750851, bgo#751258, bgo#751259, bgo#751502,
    bgo#751390, bgo#751579, bgo#751659, bgo#751660, bgo#751662,
    bgo#751970, bgo#752022, bgo#751988, bgo#752021, bgo#752080,
    bgo#752081.
* Sat Apr 18 2015 zaitor@opensuse.org
- Update to version 1.12.22:
  + Improve ODF import/export of additional axes (bgo#746321).
  + Fix ODF export of styles for additional axes (bgo#746621).
  + Simplify export of SEC and SECH to ODF (bgo#747211).
  + Harden ODF import against fuzzed files (bgo#747447,
    bgo#747448).
  + Fix ODF import/export of unlinked checkboxes and radio buttons.
  + Plug leak in ODF import and export (bgo#747590).
  + Improve pattern fill round trip through ODF.
  + Fix export of Ring plots to ODF (bgo#747763).
  + Fix import/export of Pie charts from/to ODF (bgo#747807).
  + Add more determinism to ODF export (bgo#747916).
  + Fix signal handling while running Python (bgo#744638).
  + Implement absolute anchoring for sheet objects.
  + Make graphs (and images) not resize with cells by default
    (bgo#684450).
  + xlsx import/export of log axis.
  + xlsx export of multiple plots in chart.
  + Fix xlsx import of multiple axes.
  + Fix xlsx title export problem.
  + Fix xlsx export problem with series' style.
  + Fix xlsx import/export of sheet tab text colour.
  + Improve test suite.
  + Actually implement DECIMAL.
  + Fix BETA problem with special case.
  + Fix MIDB and REPLACEB length check.
  + Fix PERMUATIONA corner case.
  + Fix RANDLOG.
  + Fix RANDGEOM to use same distribution as R.DGEOM.
  + Improve xlsx roundtrip of GOStyle.
  + Improve reading of xlsx theme colours.
  + Plug leaks.
  + Fix REPLACEB problem (bgo#747210).
  + Fix sheet filter problem.
  + Minor R.DNORM improvement.
  + Improve RAYLEIGH accuracy.
  + Improve R.QCAUCHY accuracy.
  +  Add TANPI and COTPI functions.
* Thu Mar  5 2015 dimstar@opensuse.org
- Update to version 1.12.21:
  + ODF import/export general plot data specifications
    (bgo#743818).
  + ODF import/export the z-index for line objects.
  + Fix ODF import of stroke colours of sheet objects.
  + Fix ODF import/export of fill colour and type (bgo#744051).
  + Fix ODF import/export of marker fill and outline colours.
  + Improve ODF export of manually positioned charts in multi-chart
    graphs (bgo#743789).
  + Fix ODF export of serieslines styles.
  + Fix ODF import/export of axes label visibility (bgo#743788).
  + ODF import/export additional axislines.
  + Fix ODF import/export of fonts in charts (bgo#744632).
  + ODF import/export additional axes (bgo#743787).
  + Fix ODF style import of secondary plots (bgo#744930).
  + Fix ODF style export for data points in plots (bgo#745091).
  + Implement xlsx import of sheet widgets.
  + Implement xlsx export of sheet widgets.
  + Fix xlsx import/export of patterns.
  + Plug leaks.
  + Arrow properties editor (bgo#158327).
  + Fix xlsx export of line style None.
  + Fix search-and-replace problem with text format.
  + Fix xlsx import/export of gradients.
  + Fix undo problems with scrollbars.
  + Fix spinner properties dialog.
  + SheetObjectImage fixes.
  + Fix problem reading images from xls.
  + Namespace fixes
  + Test suite improvements.
  + Fix various dtd version problems.
* Thu Feb  5 2015 dimstar@opensuse.org
- Update to version 1.12.20:
  + ODF import/export:
  - trendline names (bgo#743448).
  - trendline affinity & dimensions.
  - major & minor chart axis tick marks.
  - chart axis min and max formulae.
  - series fill types (bgo#743613).
  - marker outline colour.
  - axis positions.
  - series lines (bgo#743785).
  - all plots in a chart (bgo#743786).
  + ODF export all charts in a graph.
  + Fix ODF export of single cell ranges in graphs (bgo#743619).
  + xlsx chart import: fix font family name.
  + xlsx import/export trend line names.
  + Fix gda plugin compilation (bgo#743506).
  + Fix xlsx export problem with auto markers.
  + Import/export xlsx chart axis min/max/steps.
  + Export xlsx chart axis tick marks.
  + Fix xlsx problem with inverted axis.
  + Export sliders as scrollbars for xls.
  + Fix xls loading of horizontal scrollbars (bgo#743754).
  + Plug leaks.
  + Fix xlsx comment export.
  + Make XL see our exported xlsx axes.
  + Fix xlsx import/export of axis font info (bgo#743822).
- Drop gnumeric-add-gda-missing-include.patch: fixed upstream.
* Wed Jan 28 2015 zaitor@opensuse.org
- Update to version 1.12.19:
  + Add latex fragment exporter of visible rows only (bgo#739512).
  + Fix ants problems.
  + Plug leaks.
  + Pay more attention to union access rules.
  + Attempt a fix for clipboard crash (rh#1160975).
  + Truncate long strings for display in stf import.
  + Fix crash on closing a graph sheet.
  + Fix undo crash with conditional formatting and insert row
    (bgo#741197).
  + Fix xlsx export of HYPGEOMDIST.
  + Fix xlsx export of document properties.
  + Fix multihead issue with graph windows.
  + Improve test suite.
  + Reorganize icon handling.
  + Allow removing a specific item from the history (bgo#735305).
  + Fix GNM_HALIGN_DISTRIBUTED rendering (bgo#726155).
  + Restore translations of function help texts.
  + Fix import of extended float formula results from wk4 files.
  + Fix ADDRESS problem.
  + Fix sheet-filter problem with errors (bgo#742601).
  + Improve error handling for .gnumeric a bit.
  + Improve xlsx graph import: line colour; marker size; marker
    color; no lines; bounding box; trend lines;
    regressionequations; axis label.
  + Improve xlsx graph export: line style; bar/col direction;
    marker shape; marker size; marker color; axis label; chart
    title; trend lines.
  + Improve xlsx export: default col widths; schema validity.
  + Improve modifier handling (bgo#743130).
  + Fix import of extended floats from wk4 files (bgo#739679).
- Add gnumeric-add-gda-missing-include.patch: Fix build. Patch
  taken from upstream git.
* Fri Sep 26 2014 zaitor@opensuse.org
- Update to version 1.12.18:
  + Improve documentation (bgo#733466).
  + Add warning dialog (bgo#733352).
  + Fix rich text roundtrip through ODF (bgo#737039).
  + Fix dialogs behavior in full screen mode (bgo#736395).
  + Save axis format to xls (bgo#736656).
  + Fix recent files dialog crasher (bgo#737261).
  + Fix xls export problem (bgo#733771).
  + Update WEEKDAY function.
  + Fix xlsx export problem for strings (bgo#736202).
  + Improve xlsx import of rich text.
  + Text suite improvements.
  + Fix minor ods rich text import problem.
* Wed Jul 16 2014 dimstar@opensuse.org
- Update to version 1.12.17:
  + Fix UMR (bgo#730727).
  + Fix crashes on exit (bgo#730857, bgo#730884).
  + Handle value formats for xlsx export (bgo#724517).
  + Improve xlsx import/export of rich text (bgo#726189).
  + Fix solver critical.
- Changes from version 1.12.16:
  + Fix database-range import from ODF (bgo#730197).
  + Improve chart roundtrip through ODF (bgo#728197).
  + Fix export of non-ODF interpolation types to ODF.
  + Fix export of titles and subtitles to ODF (bgo#730397).
  + Fix axis sub-element order in ODF export (bgo#730397).
  + Fix undo crash related to hyperlinks (bgo#730466).
  + Start moving off GtkUIManager.
  + Clean out old #ifdef.
  + Fix ods series marker import/export.
  + Fix plan-perfect issue (deb#748054).
  + Make installtion work without scrollkeeper.
  + Improve import/export testing (bgo#730397).
  + Speed up certain large ranges of conditional formatting.
  + Work towards making ods export deterministic.
- Changes from version 1.12.15:
  + Fix chart size in ODF import (bgo#728278).
  + Improve chart roundtrip through ODF (bgo#728197).
  + Export centre-across-selection in a way LO can understand
    (bgo#726010).
  + Improve format roundtrip through ODF.
  + For xlsx, don't complain over "ext" elements.
  + xlsx graph import improvements.
  + Attempt a fix for tabs appearance with gtk+ 3.12 (bgo#728465).
  + Make it possible to have all callables as python functions
    (bgo#728611).
  + Improve format roundtrip through ODF.
  + Plug leaks.
  + Make search dialog non-modal again (bgo#728817).
* Sun Apr 13 2014 zaitor@opensuse.org
- Update to version 1.12.14:
  + Improve format import from ODF files.
  + Plug leaks.
  + xlsx conditional format fixes (bgo#726202).
  + Fix semantics of conditional format operators (bgo#726806).
  + Fix xlsx quotes in formula strings (bgo#726824).
  + Fix xls export of rich text.
  + Fix problems with large, circular farms of VLOOKUP etc
    (bgo#723894).
  + Let goffice handle conditional number formats.
  + Attempt a workaround for Ubuntu scroll bars.
  + Fix odf parse problems.
  + Fix array editing.
  + Fix column/row header colouring problem (bgo#728007).
* Wed Mar 19 2014 dimstar@opensuse.org
- Update to version 1.12.13:
  + Fix export of comboboxes to ODF.
  + Fix export of help messages to ODF.
  + Import invisible alignment characters in number formats from
    ODF (bgo#725852).
  + Fix fill-alignment export/import to and from ODF (bgo#726035).
  + Fix distributed-alignment export to ODF (bgo#726035).
  + Fix ODF roundtrip of "center accross selection" (bgo#726010).
  + Improve ODF roundtrip of conditional formats (bgo#726201).
  + Fix import & export of cell indent from/to ODF.
  + Fix ODF roundtrip of underlines.
  + Fix tooltip position for scale or RTL sheets (bgo#725941).
  + Really fix the hyperlink tips persistence (bgo#706659).
  + Support volatile functions.
  + Improve testing.
  + Import/Export super/subscript fonts to xlsx (bgo#726035).
  + Import xlsx auto-filters (bgo#725460).
  + Update Gnumeric schema.
  + Fix rich text problem (bgo#726086).
  + Improve xls import/export of conditional formats (bgo#726202).
  + Fix case sensitivity for conditional formats (bgo#726246).
  + Fix minor conditional format GUI issues.
  + Plug leak.
  + Fix font dialog problem with underline.
  + Fix crash reading strange xls file (rh#1076912).
  + Fix problem clearing existing values in some xlsx cells
    (bgo#726297).
  + Fix criticals for dynamic deps in conditional formats
    (bgo#726163).
  + Fix LOG2 problem (bgo#726464).
* Tue Mar  4 2014 dimstar@opensuse.org
- Update to version 1.12.12:
  + Many ODF fixes (bgo#724487, bgo#724568, bgo#724763,,bgo#724761,
    bgo#724516, bgo#724898, bgo#725115, bgo#725228, bgo#725258,
    bgo#725321, bgo#725458.
  + Provide Undo for sheet reordering via tab dragging
    (bgo#725540).
* Sun Feb 16 2014 dimstar@opensuse.org
- Update to version 1.12.11:
  + Fix hang on xls/biff7 save (bgo#724399).
  + Release infrastructure improvements.
  + Improve testing for xls/biff7.
* Wed Feb 12 2014 dimstar@opensuse.org
- Update to version 1.12.10:
  + Extend POCHHAMMER to negative values.
  + Improve accuracy of BETA and BETALN.
  + Improve accuracy of BESSELJ and BESSELY.
  + New functions: IMGAMMA, IMFACT, IMIGAMMA, IGAMMA.
  + Avoid some overflows in IMGAMMA.
  + Fix tabulation truncation issue.
  + Fix handling of dashes on ODF import (bgo#719509).
  + Suppress some warnings in xlsx import (bgo#719680).
  + Accept 3D values for vector data (bgo#722294).
  + Improve performance of ant-int cursor (bgo#381011).
  + Fix filled sheet objects properties box on cancelling
    (bgo#723745).
  + Resurrect list of functions on the new Gnumeric wiki.
  + Fix timeout related critical in ItemGrid.
  + Fix solver problem with constraints.
  + Improve accuracy of R.PNORM and R.PLNORM for large arguments.
  + Improve accuracy of R.QCAUCHY.
  + Improve accuracy of R.DHYPER, R.DBINOM, R.DNBINOM, R.DPOIS,
    RAYLEIGH.
  + Save some vertical space between toolbars.
  + Bugs fixed: bgo#720353, bgo#720425, bgo#720426, bgo#720358,
    bgo#719349, bgo#715002, bgo#557815, bgo#719997, bgo#722074,
    bgo#723600, bgo#723894, bgo#720306.
* Wed Dec 25 2013 zaitor@opensuse.org
- Drop psiconv-devel BuildRequires, as I doubt there are any users
  left of this.
* Mon Dec 16 2013 zaitor@opensuse.org
- Exchange scrollkeeper BuildRequires for
  rarian-scrollkeeper-compat. Scrollkeeper was dropped from
  distribution.
- Stop rm -r %%{buildroot}%%{_localstatedir}/scrollkeeper, after the
  switch to rarian-scrollkeper-compat it does not exist any more.
* Mon Dec  2 2013 dimstar@opensuse.org
- Update to version 1.12.9:
  + Implement double click for graph sheets (bgo#712216).
  + Fix drop-down sizing (gtk+ regression (bgo#710749).
  + Improve accuracy of R.QCAUCHY, R.QGAMMA, R.QCHISQ, R.QBETA,
    R.QF, R.QTUKEY, R.QSNORM, R.QST, COMBIN, PERMUT, POCHHAMMER,
    FACT, GAMMA, ACOTH and bessel functions with large non-integer
    alpha.
  + Restore sheet reordering by drag.
  + Incorporate new tests from crlibm.
  + New functions SINPI and COSPI.
  + Improve accuracy of SIN/COS/TAN on win32.
  + Work around GTK+ ABI break (rh#1033827).
  + Fix dialog button order (bgo#710378).
  + Various Win32 fixes.
  + Fix fuzzed file problems (bgo#708091, bgo#712662, bgo#712685,
    bgo#712700, bgo#712708, bgo#712772, bgo#712788, bgo#712731,
    bgo#715003.
* Wed Oct 16 2013 firebird209@gmail.com
- Update to version 1.12.8:
  + Update/fix documentation (bgo#708679, bgo#707075, bgo#708556).
  + Fix paste into locked cells (bgo#702292).
  + Fix radio buttons behavior in covariance dialog. (bgo#707595).
  + Add a border around font selector in cell format dialog
    (bgo#708567).
  + Fix fuzzed file crash (bgo#707875).
  + Use lighter green for function markers (bgo#708573).
  + Fix item cursor problem (bgo#709320).
  + Fix win32 compilation.
* Thu Sep  5 2013 mls@suse.de
- Add libperl_requires, as we link against libperl and thus
  need a specific version of perl.
* Sun Sep  1 2013 zaitor@opensuse.org
- Update to version 1.12.7:
  + Extend BESSELJ and BESSELY to handle fractional order
    (bgo#706720).
  + Fix crash with split pane (bgo#707047).
* Wed Aug 28 2013 dimstar@opensuse.org
- Update to version 1.12.6:
  + Fix crash on corrupted files (bgo#706526, bgo#706413,
    bgo#706417).
  + Fix save style performance issue (bgo#699045).
* Tue Aug 20 2013 zaitor@opensuse.org
- Update to version 1.12.5:
  + Improve ODF import of cells with links (bgo#704022).
  + Fix import of multi-paragraph text from ODF (bgo#704391).
  + Fix ODF export of empt rows (bgo#704438).
  + Export custom shapes (bgo#704421).
  + Fix export to ODF of empty cells with default column styles
    (bgo#704563).
  + Improve import to ODF of empty cells with default column
    styles (bgo#704563).
  + Speed up loading of some ODF files (bgo#704422).
  + Fix ODF style import (bgo#704563).
  + Fix crash on corrupted files (bgo#704636, bgo#705385,
    bgo#705421, bgo#705420, bgo#706075).
  + Fix ODF import of charts with series consisting of multiple
    ranges (bgo#704742).
  + Fix ODF export of charts with series consisting of multiple
    ranges.
  + Implement input message editing (bgo#705310).
  + Fix export of input-message only validations (bgo#705384).
  + Fix warnings (Part of bgo#705313).
  + Show input messages (bgo#705310).
  + Fix Excel XML import (bgo#705223).
  + Fix documentation (bgo#705541).
  + Avoid crashing when printing sheet object widgets from
    ssconvert (bgo#705638).
  + Fix printing of sheet object widgets (bgo#705650, bgo#705653).
  + Use current GTK style when printing sheet object widgets from
    Gnumeric (bgo#705684).
  + Scale tiny buttonssheet objects when printing (bgo#705689).
  + Bring back gda support (bgo#604690).
  + Fix text wrap inside sheet objects (bgo#704417).
  + Fix export of scatter/bubble plots to xls (bgo#705311).
  + Fix crash when importing fuzzed chart from xls (bgo#705353).
  + Accept <graph:Type> nodes in guppi graphs (deb#718594).
  + Avoid crashing after destroying a SheetWidgetAdjustment
    associated widget (bgo#705692).
  + Fix crazy parsing problem (bgo#704109, bgo#704140).
  + Fix crashes on corrupted files (bgo#704102, bgo#704004,
    bgo#704325, bgo#704562, bgo#705866).
  +  Fix conditional format problem (bgo#704445).
  +  Fix R1C1 parsing issue (bgo#705637).
  +  Improve handling of large-area conditional styles.
  +  Fix (?) Applix pattern importer (bgo#705946).
  +  Fix FMR (bgo#705913).
  +  Fix sheet removal dep problem (bgo#706095).
  +  Fix test failure (bgo#705947).
- Exchange libgda-devel for pkgconfig(libgda-5.0) and
  pkgconfig(libgda-ui-5.0) BuildRequires.
* Sat Jul 20 2013 dimstar@opensuse.org
- Update to version 1.12.4:
  + Improve xlsx export of Gnumeric functions.
  + Improve xlsx import of Excel 2010 functions.
  + Improve xls import of Excel 2010 functions.
  + Fix documentation of r.q* and r.*nbinom (bgo#703164).
  + Add Excel 2010's BETA.DIST.
  + Fix crash on corrupted files (bgo#703149, bgo#703215,
    bgo#703625, bgo#703895).
  + Fix import of sxc files (bgo#703249).
  + Fix TDIST Import/Export from/to ODF.
  + Write manual legend position to ODF (bgo#703362).
  + Fix position handling in strict ODF export.
  + Don't attempt to add a path item when there is no path object
    (bgo#703052).
  + Improve accuracy for 2-argument ERF.
  + Fix crashes on corrupted files (bgo#703143, bgo#703307,
    bgo#703306).
  + Fix --with-long-double tests (bgo#703397).
  + Fix problems saving auto filters to xls (bgo#703308).
  + Improve handling of large graph ranges (bgo#703546).
  + Fix analysis issue with translations (bgo#703355).
  + Fix COUNTIF (etc) pattern matching (bgo#703770).
* Sat Jun 29 2013 zaitor@opensuse.org
- Update to version 1.12.3:
  + Fix border handling for merged cells in LaTeX export.
  + Add a keyboard shortcut to jump to the current cell indicator.
  + Improve xlsx import of new stat function names.
  + Consolidate comment, hyperlinks, names documentation.
  + Update documentation for Manage Sheets, R1C1 notation, sheet
    ranges. 1.12 updates, typo corrections, misc.
  + Fixes to the gnumeric and ssconvert manual pages.
  + Improve xlsx import of style-only cells.
  + Don't write empty cells to .gnumeric.
  + Add MPSEUDOINVERSE function.
  + Fix missing translation of certain function examples.
  + Add new SNORM.DIST.RANGE function.
  + Fix critical when last row deleted.
  + Fix criticals in about dialog.
  + Introspection fixes.
  + Workaround problems with automake 1.13.
  + Remove gobject property strings from translation corpus.
  + Bugs fixed: bgo#699631, bgo#699897, bgo#700732, bgo#700969,
    bgo#700994, bgo#700792, bgo#700018, bgo#699746, bgo#699710,
    bgo#701436, bgo#698519, deb#699054, bgo#701834, bgo#702146,
    bgo#702169, bgo#702197, bgo#698388, bgo#702205, bgo#702219,
    bgo#702285, bgo#702288, bgo#702364, bgo#702409, bgo#702486,
    bgo#702485, bgo#702498, bgo#702322, bgo#702689, deb#621735,
    deb#530462, bgo#702868, bgo#702407, bgo#702612, bgo#702615,
    deb#464732, bgo#700596, bgo#700797, bgo#700156, bgo#702126,
    bgo#702833, bgo#699579, bgo#699647, bgo#551457, bgo#700294,
    bgo#700295, bgo#700132, bgo#700132, bgo#701604, bgo#702101,
    bgo#702182, bgo#702218, bgo#702267, bgo#702277, bgo#702379,
    bgo#702658, bgo#703006.
* Fri May  3 2013 dimstar@opensuse.org
- Update to version 1.12.2:
  + Improve import of header/footer info from ODF.
  + Fix plot placement in ODF import.
  + Support ODF's title tag in headers and footers.
  + Fix locale directory.
  + Update documentation.
  + Bugs fixed: bgo#698389, bgo#698388, bgo#698535, bgo#635217,
    bgo#347013, bgo#696533, bgo#697107, bgo#697281, bgo#695529,
    bgo#695031, bgo#696826, bgo#659317, bgo#697293, bgo#697634,
    bgo#683494, bgo#697927, bgo#697850, bgo#608780, bgo#577768,
    bgo#654211, bgo#661800, bgo#686156, bgo#685446, bgo#695839,
    bgo#590889, bgo#689283, bgo#698424, bgo#625687, bgo#698680,
    bgo#698772.
- Drop gnumeric-configure.patch: fixed upstream.
- Drop gnome-common BuildRequires and call to gnome-autogen.sh, as
  we no longer carry any patches.
* Tue Mar 19 2013 dimstar@opensuse.org
- Update to version 1.12.1:
  + Introspection fixes (bgo#684159).
  + Some documentation fixes.
  + Show argument names for python functions (bgo##690681).
  + Fix loading of ODF files with named expressions (bgo#690925).
  + Avoid unncessary sheet specification in analysis tools
    (bgo#691892).
  + Fix sensitivity tests for 2-factor anova dialog (bgo#693980).
  + Fixed aspect ratio for graph sheets (bgo#691472).
  + Replaced all GtkTable instances by GtkGrid.
  + Make the row and column header clickable even when indented.
  + Fix horizontal and vertical pane positions after indentation.
  + Fix a few compiler warnings.Fix a few compiler warnings.
  + Always compile ssconvert, ssindex, and ssgrep.
  + New utility: ssdiff.
  + Remove disabled corba plugin.
  + Other bugs fixed: bgo#690929, bgo#687926, bgo#109442,
    bgo#625544, bgo#691913, bgo#691984, bgo#654495, bgo#674954,
    bgo#693761, bgo#694741, bgo#694777, bgo#364291.
- Add gnumeric-configure.patch: Fix instal location of locale
  files.
- Add gnome-common BuildRequires and call to gnome-autogen.sh, as
  above patch touches the build system.
- Reenable pkgconfig(gobject-introspection-1.0) BuildRequires:
  gobject-introspection building has been corrected.
* Mon Jan  7 2013 dimstar@opensuse.org
- Update to version 1.12.0:
  + Fix xlsx save problem (bgo#690203).
- Changes from version 1.11.91:
  + Update the Gnumeric manual.
  + Fix format problem.
- Drop gnumeric-missing-return.patch: fixed upstream.
* Tue Dec 18 2012 crrodriguez@opensuse.org
- Add %%perl_requires: application links to libperl.so which is not
  versioned and %%perl_version dependant.
* Tue Dec 11 2012 vuntz@opensuse.org
- Update to version 1.11.90:
  + ODF import/export improvements (bgo#662057, bgo#683739,
    bgo#686789, bgo#687243, bgo#687693)
  + Fix encounter with macro sheets on xls import (bgo#684646)
  + Fix xlsx save performance problems (bgo#662058, bgo#685530)
  + Save all settings in stf export (bgo#685077)
  + Fix cell overflow in case of marked up scientific format
    (bgo#686540)
  + Fixed indentation in cell format dialog (bgo#683576)
  + Do not use filtered out values in graphs (bgo#687209)
  + Fixed crash on interprocess image copying (bgo#687414)
  + Fix sheet focus after resizing (bgo#687188)
  + Unselect sheet objects on closing to avoid leaks (bgo#688094)
  + Make .gnumeric use fewer style rectangles for the same style.
  + Short-circuit column resize for large stf imports (bgo#686858)
  + Enhance POWER to do root of negative numbers (bgo#687269)
  + Fix interaction with ibus & fcitx (bgo#684511)
  + Fixed introspection annotations (bgo#682514)
- Add gnumeric-missing-return.patch: fix missing return value.
* Sun Sep 16 2012 dimstar@opensuse.org
- Update to version 1.11.6:
  + Some documentation updates.
  + Fix implicit ')' for array functions. (bgo#680548)
  + Add FLIP function. (bgo#680511)
  + Allow unordered abscissae in INTERPOLATION. (bgo#680510)
  + Fix INTERPOLATION crash. (bgo#680711)
  + Suppress range markers that should be in an external workbook.
    (bgo#680718)
  + Fix layering of sheet objects in ODF export and import.
    (bgo#681009)
  + Export/import opacity of fill-colours to/from ODF. (bgo#681009)
  + Some basic custom-shape support in ODF import.
  + Map captions onto text rectangles on ODF import.
  + Add new autofilter op. (bgo#647401)
  + Provide new saver for uncompressed Gnumeric xml. (bgo#672622)
  + Do not change workbook save info when exporting. (bgo#672323)
  + Fix format selection on export. (bgo#681316)
  + Add Repeat Export menu item. (bgo#594154)
  + Fix component references issues. (bgo#680190)
  + Fix linear averaging interpolation. (bgo#680723, bgo#680918)
  + Support semi-transparent fonts in cells. (bgo#678176)
  + Fix sheet object frame label change. (bgo#681307)
  + Fix xls read crash.  (bgo#679992)
  + Dependents code cleanups.
  + Make cells regular dependents.
  + Fix non-linear solver crash.  (bgo#680719)
  + Improve inter-workbook recalculations.
* Thu Aug 16 2012 dimstar@opensuse.org
- Update to version 1.11.5:
  + Add support for introspection (bgo#670271)
  + Teach non-linear solver about constraints (bgo#620368)
  + Avoid too many hash collissions for dense sheets
  + Speed up operations that iterate over cells in large areas
  + Fix problems with linear solvers and cross-sheet target
  + Fix python-loader vs. goffice interface problem
  + Add solver report
  + Solver translation fixes
- Changes frmo version 1.11.4:
  + ODF import and export improvements (bgo#672815, bgo#675820,
    bgo#675821, bgo#676063, bgo#676064, bgo#676289, bgo#676441,
    bgo#676339, bgo#676535, bgo#676596)
  + Export in-cell font colours (bgo#675210)
  + Fix warning on column insertion (bgo#675224)
  + Add underline button to formatted text dialog for sheet
    objects, commemts, etc
  + Fix consolidate tool (bgo#670155)
  + Fix Wilcoxon Mann Whitney Test in the presence of empty cells
  + Add single sample t-test
  + Improve Mann-Whitney test to allow for two separate data ranges
  + Fix fullscreen criticals
  + Other bugs fixed: bgo#677956, bgo#677967, bgo#674814,
    bgo#625702, bgo#678258, bgo#678259, bgo#678520, bgo#675913,
    bgo#648676, bgo#675089, bgo#675000, bgo#674914, bgo#674954,
    bgo#675955, bgo#678580.
- Replace python-gobject2-devel BuildRequires with
  pkgconfig(pygobject-3.0): Upstream ported to gtk+ 3.0
- Add pkgconfig(gobject-introspection-1.0) BuildRequires: enable
  the new introspection support. Note: This is currently commented
  out, as the support is not functional yet (bgo#684159).
* Tue Jul 24 2012 dimstar@opensuse.org
- Recommend mimehandler(x-scheme-handler/ghelp): as gnumeric uses
  ghelp:gnumeric to launch the help, we recommend to have a mime
  handler that can handle this schema (bnc#719679).
* Thu Apr 26 2012 vuntz@opensuse.org
- Update to version 1.11.3:
  + Relicencing to GPLv2/GPLv3.
  + Import/export fixes for xls and ods.
  + Export fixes for rich text and .gnumeric.
  + Allow pattern matching for VLOOKUP/HLOOKUP.
  + New function COVARIANCE.S.
  + Fix various crashes.
  + Performance and memory usage improvements.
  + Several other bug fixes.
  + Bugs fixed: bgo#667489, bgo#670692, bgo#671267, bgo#671461,
    bgo#671461, bgo#671461, bgo#671494, bgo#671508, bgo#671513,
    bgo#671617, bgo#671745, bgo#671845, bgo#671863, bgo#672154,
    bgo#672319, bgo#672330, bgo#672489, bgo#672716, bgo#673129,
    bgo#673256, bgo#673447, bgo#674341, rh#803904.
- Change license from GPL-2.0+ (which was wrong) to "GPL-2.0 or
  GPL-3.0", following upstream change.
* Sat Mar  3 2012 dimstar@opensuse.org
- Update to version 1.11.2:
  + Colour the range expressions to match the range cursor.
  + Implement ctrl-click cell deselection.
  + Fix LaTeX export of cyrillic.
  + Fix function tool tip.
  + Delay function completion tooltip.
  + Import inline text from xlsx files.
  + Fix rich text import from xlsx.
  + Fix data shuffle.
  + Clarify the skew-t and skew-normal descriptions.
  + Fix EXACT.
  + Fix editing of decimals.
  + Fix edit line display.
  + Avoid recalculation on pure comment deletion.
  + Fix formula interpretation in plot series.
  + Don't destroy a sheet object when inserting it.
  + Improve parsing on numbers with non-ascii digits.
  + Make solver check for exceeding the time limit.
  + Fix object life-cycle problems in solver.
  + Fix multihead problem with format dialog.
  + Fix auto-expression problem with sheet deletion.
  + Fix ellipsizing of auto-expression.
  + Fix auto-expression of single cell when moved.
  + Fix problems with underlines and rotated cells.
  + Fix multihead problem with auto-expressions.
  + Fix allocate-free mismatch in sheet management dialog.
  + Fix paste special undo problem.
  + Fix F4 (abs/rel-cycling) bug.
  + Fix minor function name completion bug.
  + Fix abs/rel stickiness in expression entry.
  + Minor quit-dialog improvements.
  + Put DataShuffle back on the menus.
  + Resurrect the splash screen from bit rot.
  + Make sheet removal respect manual recalculation.
  + Bugs fixed: bgo#632156, bgo#610696, bgo#666340, bgo#668685,
    bgo#668683, bgo#668936, bgo#669083, bgo#669184, bgo#670232,
    bgo#670558, bgo#555519, bgo#670603, bgo#662237, bgo#669648,
    bgo#667152, bgo#667702, bgo#668625, bgo#668624, bgo#668691,
    bgo#670449, bgo#671192.
- Add explicit pkgconfig(libgsf-1) and pkgconfig(libxml-2.0)
  BuildRequires.
- Remove xz BuildRequires now that it comes for free in the
  buildsystem.
* Thu Jan 19 2012 vuntz@opensuse.org
- Add explicit pkgconfig() BuildRequires: glib-2.0, pango,
  pangocairo. Those were all implicitly brought in before.
- Change goffice-devel BuildRequires to pkgconfig(libgoffice-0.10),
  to avoid any confusion between goffice-0_8 and goffice.
- Stop changing Name of gnumeric.desktop: it's already fine
  upstream.
* Mon Jan  9 2012 dimstar@opensuse.org
- Update to version 1.11.1:
  + Show range selection cursors even while selecting new regions
    and on other sheets
  + Fixed expression range cursor behavior [bgo#664852]
  + Build fixes relating to embedded ui files [bgo#664828]
- Changes from version 1.11.0:
  + Highlights:
  - Gnumeric uses GTK+ 3, not GTK+ 2.
  - Gnumeric uses GTK+'s ui manager files, not libglade.
  - Gnumeric uses GSettings, not GConf.
  - Lots of small bug fixes.
  + Various fixes for xls, xlsx and ODF compatibility.
  + Add support for SVG images.
  + Clarify the distinction beween open/save and import/export.
  + Add HPFILTER function calculating the Hodrick Prescott Filter.
  + Enable markup selection in scientific format selector.
  + Fix IRR and other functions acting on paired data set when
    called with fixed arrays.
  + Remove obsolete Hildon port and obsolete code.
  + Bugs fixed: bgo#304007, bgo#356711, bgo#425685, bgo#455712,
    bgo#535473, bgo#584380, bgo#603533, bgo#627509, bgo#628472,
    bgo#634803, bgo#645673, bgo#645842, bgo#651561, bgo#655877,
    bgo#656418, bgo#656799, bgo#657036, bgo#657506, bgo#658140,
    bgo#658194, bgo#658223, bgo#658639, bgo#658916, bgo#658981,
    bgo#658982, bgo#659246, bgo#660241, bgo#660242, bgo#660248,
    bgo#660605, bgo#660657, bgo#661213, bgo#661405, bgo#661720,
    bgo#661855, bgo#661958, bgo#662056, bgo#662056, bgo#662149,
    bgo#662310, bgo#662331, bgo#662361, bgo#662412, bgo#662413,
    bgo#662472, bgo#662474, bgo#662551, bgo#663078, bgo#663117,
    bgo#663135, bgo#663216, bgo#663663, bgo#663671, bgo#663712,
    bgo#663802, bgo#664243, bgo#664351, bgo#664447, bgo#664692,
    bgo#664754, deb#642135, lp#262777.
  + Updated translations.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
- Replace gtk2-devel BuildRequires with pkgconfig(gtk+-3.0),
  following upstreams change to GTK 3.
- Drop gconf2-devel BuildRequires: with the move to GSettings this
  is no longer needed.
- Remove gconf schema handling macros: gconf is no longer used.
- Clean spec-file using spec-cleaner.
- Remove explicit Requires from the -devel package: they are added
  automatically the pkgconfig()-way.
* Tue Oct 25 2011 vuntz@opensuse.org
- Use a more generic hack in %%setup to remove incomplete
  translations created by translation-update-upstream. Should fix
  build breakages created when translation-update-upstream is
  updated and adds new translations.
* Mon Oct  3 2011 vuntz@opensuse.org
- Remove unneeded mime-info-to-mime call in %%install as there is no
  old MIME definition, and also remove now unneeded
  shared-mime-info BuildRequires.
* Mon Aug  1 2011 vuntz@opensuse.org
- Update to version 1.10.17:
  + Import and Export fixes for ODF (bgo#652492, bgo#654214,
    bgo#653186, and more)
  + Import and Export fixes for xlsx (bgo#655010, and more)
  + Fix import of Excel 2003 xml files in non-C locale.
    (bgo#655554)
  + Allow document properties to be edited and added.
  + Add an interface for conditional styles.
  + Provide undo for cut between 2 gnumeric processes. (bgo#640922)
  + Implement printing of errors as blanks, dashes or NAs.
  + Bugs fixed: bgo#648676, bgo#652802, bgo#653378, bgo#654538,
    bgo#655389, rh#726860.
* Fri Jul  8 2011 vuntz@opensuse.org
- Re-enable translation-update-upstream as bnc#703739 is fixed.
* Wed Jul  6 2011 vuntz@opensuse.org
- Disable translation-update-upstream because it breaks the build
  (bnc#703739).
* Fri Jun 17 2011 vuntz@opensuse.org
- Update to version 1.10.16:
  + Add exporter for ECMA-376 2nd edition.
  + Import and Export fixes for ODF
  + Import and Export fixes for xlsx
  + Switch to using goffice's complex math.
  + Fix leaks.
  + Some documentation improvements.
  + Bugs fixed: bgo#649714, bgo#649675, bgo#650941, bgo#651173,
    bgo#646612, bgo#645580, bgo#644496, bgo#532635, bgo#652690,
    bgo#652689, bgo#650761, bgo#650764, bgo#599901, bgo#651667.
- Stop using source service to download the tarball, as Factory
  will move away from this.
* Sun May 22 2011 dimstar@opensuse.org
- Update to 1.10.15:
  + Import and Export fixes for ODF
  + Fix memory leaks and memory usage generally
  + Initial support for Works files.
  + Bugs fixed: bgo#645805, bgo#647247, bgo#646641, bgo#648354,
    bgo#649092, bgo#649139, bgo#649484, bgo#649592, bgo#649591,
    bgo#649406, bgo#649714, bgo#649711, bgo#649713, bgo#649906,
    bgo#649914, bgo#649851, bgo#650261, bgo#650125, bgo#650639,
    bgo#650640, bgo#650625, bgo#649901, bgo#644197, bgo#155003,
    bgo#650639, bgo#647492.
* Thu Apr 28 2011 vuntz@opensuse.org
- Do not pass --libexecdir to configure: it's not needed.
* Mon Apr 18 2011 dimstar@opensuse.org
- Update to 1.10.14:
  + bgo#641626: Fix width of translated lists in various dialogs
  + bgo#641355: Allow function tooltips to be closed temporarily
  + Minor histogram improvements.
  + bgo#395631: Trigger configurable text importer on paste of tabs
  + bgo#643971: Fix ctrl-end in presence of hidden rows.
  + bgo#644189: Fix import of dbf files with more than 65536 rows.
  + bgo#641709: Fix cursor position inside a cell edited in a
    zoomed sheet.
  + Add GSettings schemas.
  + bgo#641581: Import wide sc files.
  + bgo#613273: Fix problem with single-cell names and 'r'-type
    arguments.
  + Plug memory leaks.
  + bgo#642477: Fix stf import problem diagnosed by Andreas.
  + Restore toolbar positioning code.
  + rh#680572: Fix xml reading of constraints.
  + Fix lpsolve/glpk writing of affine part.
  + bgo#644189: Improve dbf codepage support.
  + bgo#644217: Improve date format consistency in document
    properies.
  + bgo#533795: Hopefully make print preview work on win32.
  + bgo#644982: Improve quit dialog's non-ascii handling.
  + bgo#645287: Allow templates for multi-sheet ssconvert.
  + Improve "dif" output.
  + ODF import/export improvements (including bgo#640701).
  + xlsx import improvements (bgo#642850, bgo#643814,
    bgo#642941, bgo#643808, bgo#643815, bgo#643874).
  + Fix crashes (bgo#642850, bgo#645722, bgo#645209, bgo#645555).
- Add GSettings schemas handling, with %%glib2_gsettings_schema_*
  macros.
- Convert to source service: download tar.bz2 file and update .spec
  file with correct version.
* Sun Mar 20 2011 dimstar@opensuse.org
- Update to version 1.10.13:
  + bgo#635064: Calculate residuals when using the regression tool.
  + Permit data entry by-passing autocorrection.
  + bgo#636131: Work around OpenOffice date formatting bugs.
  + bgo#636158: Export text formats to and import from ODF.
  + bgo#636968: Fix ODF import of sheets with far forward
    references.
  + Add EEK support to EURO and EUROCONVERT.
  + Fix leaks in potentially failing analysis tools.
  + bgo#639019: Make the row and column headers and selection match
    the theme better.
  + bgo#638874: Fix locale specific sorting.
  + bgo#639086: Ensure we have sub- and sperscript icons.
  + bgo#639444: Fix advanced filter.
  + bgo#638832: Suppress function tooltips on text-formatted cells.
  + bgo#640344: Fix documentation of ATAN2.
  + bgo#636031: Only disable the formula bar when a chart sheet is
    selected.
  + bgo#637393: Make sheet objects invisible outline from .xls
    files persistent.
  + bgo#637453: Fixed arrows and line object position when zoomed.
  + bgo#637658: Fixed series lines color export to .xls.
  + bgo#637739: Fixed sheet objects position on zoomed sheets.
  + bgo#639287: Override edition-canceled property for GnmExprEntry
  + bgo#633433: Fix array intersection problem with IF.
  + Make sure columns are wide enough for dates in csv import.
  + Plug a few leaks.
  + Fix number-match issue regarding fraction.
  + bgo#638776: Fix problems with pivot reading from xls.
  + bgo#630247: Allow version-agnostic template files.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Remove wrong call to update-mime-database in %%post/%%postun.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Fri Nov 26 2010 dimstar@opensuse.org
- Update to version 1.10.12:
  + Add argument to FOURIER to separate parts.
  + bgo#630085: Extend TREND function to handle multiple regression
  + bgo#631322: Fix selection for sheet object lists and combos.
  + bgo#631327: Preserve selection for sheet object lists when we
    change content.
  + bgo#629333: Add option to sheet object lists and combos to
    enter values rather than index.
  + bgo#631570: Fix manual pagebreak handling when printing.
  + Add menu items to remove and add manual page breaks.
  + Improve the sc import.
  + bgo#632999: Fix button sensitivity in sort dialog.
  + bgo#634135: Fix ODF export of files with large formatted sheets
  + bgo#635111: Fix extensions of supported ODF files.
  + bgo#563098: Fix import of dib format images in XLS.
  + bgo#631702: Fixed maximum for col/row number in sheet resize
    dialog.
  + bgo#631717: Eliminate glade usage.
  + bgo#634149: Fixed crash in print setup.
  + Fixed image bounds in zoomed sheets.
  + bgo#632050: Fix crash related to broken xls.
  + Fix print area problem from broken xls.
  + bgo#632439: Fix printing crash.
  + bgo#633140: Partially fix problem with undefined names.
  + Fix analysis tools problems when "as values" is chosen.
  + Fix gtk+/X crash with large tooltips.
  + Take care of dead kittens.
  + bgo#634597: Fix text object clipping issue.
  + bgo#634792: Fix problem with disappearing window for empty file
  + Fix ranges-in-expression criticals.
  + bgo#634139: Add key combinations to move sheets.
  + bgo#527133: Modify quit dialog to be able to discard multiple
    files without saving.
- Remove libglade2-devel BuildRequires.
* Sat Oct  2 2010 vuntz@opensuse.org
- Update to version 1.10.11:
  + Fix image-fill, pattern and gradient export. [bgo#628762]
  + Read tab colors from OOo config in ODF files.
  + Improve some ODF chart import/export.
  + Import/export all sheet objects from and to ODF files.
  + Fix reformatting of cells on expression entry. [bgo#629303]
  + Allow multiple selection in manage sheet dialog.
  + Permit ctrl-click specification of sort columns.
  + Set ODF files to save by default as ODF files. [bgo#629962]
  + Fix ssconvert crash on form controls. [bgo#630335]
  + Improve printing of the form controls.
  + Permit choice whether to print sheet objects.
  + Export/import tick label rotation angle. [bgo#629675]
  + Read and write cell comments from/to OpenXML. [bgo#630627]
  + Revised ssconvert man page.
  + Fix several potential and actual problems highlighted by
    LLVM/clang static analysis.
  + Fix date entry problem. [bgo#630177]
  + Fix problem with inter-process empty-value paste. [bgo#629302]
  + Fix problem with inter-process object paste. [bgo#629302]
  + Allow user-defined templates. [bgo#630247]
  + Improve test suite.
* Thu Sep 30 2010 vuntz@opensuse.org
- Change libgnomedb-devel BuildRequires to libgda-devel: libgnomedb
  is dead upstream (replaced by libgdaui), and gnumeric cannot use
  libgnomedb anyway.
* Sun Sep  5 2010 vuntz@opensuse.org
- Update to version 1.10.10:
  + Significantly improve chart export and import to/from ODF.
  + Improve handling of corrupted ODF files.
  + Fix percentage style import from ODF. [bgo#627517]
  + Fix INTERPOLATION documentation. [bgo#627461]
  + Provide progress info in ODF export.
  + Improve warnings dialog in ODF import.
  + Fix button sensitivity in sort dialog.
  + Fix some interpolation and periodogram issues.
  + Fixed graph scalar data editor behavior. [bgo#628721]
  + Plug sylk importer leak.
  + Plug xml importer leak.
  + Plug odf importer leak. [bgo#627759]
  + Extend domain of IMPOWER. [bgo#627775]
  + Allow use of glib's memory profiler.
  + Fix some confusion of char vs. xmlChar.
  + Fix elapsed-time entry. [bgo#628082]
  + Fix problems with limits for date axes.
  + Improve function docs self test.
  + Fix errors in function docs.
* Tue Aug 17 2010 dimstar@opensuse.org
- Update to version 1.10.9:
  + bgo#625688: Clarify autofilter dialog
  + bgo#625966: Make the tooltips theme-independent.
  + Adjust and fix WORKDAY and NETWORKDAY.
  + bgo#626632: Fix crash on certain handcrafted ODF files.
  + bgo#626632: Fix import of some ODF 1.0 charts.
  + bgo#626648: Fix crash on paste into an empty expression entry.
  + bgo#626653: Import and export boxplots to and from ODF files.
  + bgo#626654, bgo#626655: Improve handling of corrupted ODF files
  + bgo#626781: Fix autocorrection when entering in ranges.
  + bgo#626789: Fix column wdth and row height adjustments when
    entering in ranges.
  + bgo#626861: Fix autofitting on data entry.
  + bgo#620797: Avoid some of the multiple undos when entering
    existing text in ranges.
  + bgo#626903: Adjust formats when autofitting new entries.
  + bgo#626904: Autofit rows and columns when entering an array
    expression.
  + bgo#359404, bgo#611181: Fix column and row fitting on paste.
  + Export images to ODF.
  + bgo#626961: Fix import of graphs from rich ODF files.
  + Some ring and pie plot ODF export improvements.
  + bgo#567953: Import Guppi graphs from gnumeric-1.0.x files.
  + bgo#625726: Survive malformed guppi graphs.
  + bgo#625727: Use theme foreground color for row and column
    headers.
  + bgo#625994: Force column span recalculation when switching
    between number and error.
  + bgo#626065: Fix scroll when selecting a merged cell.
  + bgo#626484: Fix objects dragging when zoomed.
  + Fix control points behavior when zooming.
  + bgo#626279: Fix in-cell editing when zoom < 100%%.
  + Survive malformed xml files.
  + bgo#533779: Fix win32 random problem.
  + bgo#627014: Fix IMPOWER problem.
  + Avoid criticals in ODS import.
  + bgo#627079: Fix problem with collect cache.
* Mon Aug  9 2010 vuntz@opensuse.org
- Update to version 1.10.8:
  + Add new Excel and Openformula units ("pica" and "picapt") to
    CONVERT.
  + Save default search settings. [bgo#105615,bgo#625185]
  + Improve configurable text export of numbers. [bgo#126444]
  + Improve horizontal fill. [bgo#594193]
  + Improve function syntax tooltips. [bgo#623317]
  + Add weekend specifier to WORKDAY and NETWORKDAYS. [bgo#172458]
  + Fix ngettext usage.
  + Fix undo text for sheet object duplication. [bgo#623557]
  + Fix additional undo entry for sheet object duplication.
    [bgo#623559]
  + Fix undo of object creation followed by duplication.
    [bgo#623566]
  + Avoid creating interacting auto filters. [bgo#607086]
  + Improve items of the cell context menu. [bgo#74359]
  + Fix various function docs issues.
    [bgo#623669,bgo#624559,bgo#625102]
  + Improve the presentation of the examples in the function
    documentation. [bgo#623455]
  + Fix HDATE and friends. [bgo#623764,bgo#625177]
  + New functions DATE2HDATE, DATE2HDATE_HEB and DATE2JULIAN.
  + Add hyperlink and comment removal menu items.
  + Add merge and unmerge menu items.
  + Add menu item to autofit column width or row height based on
    the selection only. [bgo#125595]
  + Add autofit actions to cell context menu.
  + Add new function ARRAY. [bgo#570689]
  + Add new function SORT. [bgo#59144]
  + Add menu item to wrap SORT around an existing range.
  + Show the number of rows filtered by the auto filter.
    [bgo#346002]
  + Improve function tooltips. [bgo#623322]
  + Improve expression entry range selection.
    [bgo#80725,bgo#624288,bgo#624289,bgo#624581]
  + Add preference setting to disable the extension check for the
    configurable text exporter. [bgo#594151]
  + Add optional marker to indicate that a cell contains an
    expression. [bgo#55124]
  + Add merge and unmerge items to the cell context menu.
  + Permit double-clicking of functions in the function selector.
  + Allow single merge to single merge copying. [bgo#87296]
  + Make the font style buttons override the character attributes.
    [bgo#163410]
  + Provide name completion (F4) when entering functions.
    [bgo#587084]
  + Implement access to the function selector to paste function
    names while editing cells (Shift-F4).
  + Add preference settings whether to show function name and/or
    argument tooltips.
  + Fix undo of Clear->All and Clear->Comments.
    [bgo#625151,bgo#623803]
  + Add menu items to allow clearing of filtered rows only.
  + Fix editing of hyperlinks.
  + Work around OOo's failure to correctly define its named ranges.
    [bgo#625332]
  + Remove range hightlighting while not editing expressions.
    [bgo#625361]
  + Reduce the size of the text import dialog. [bgo#625281]
  + Fix import of underlined/double underlined comments from xls.
    Part of [bgo#405951]
  + Improve xl import of underlines.
  + Correctly size the autoexpressions. [bgo#625521]
  + Fix row height dialog. [bgo#625543]
  + Add menu to specify whether to enter as array, into multiple
    cells, etc. Part of [bgo#53733]
  + Make autofilter condition changes undoable. [bgo#625143]
  + Fix strong/weak cursor display. [bgo#623241]
  + Fix regression in ms_excel_chart_read. [bgo#623960]
  + Fix a regression in chart series evaluation. [bgo#624263]
  + Fix crash in cell_calc_span. [bgo#624274]
  + Install a self-consistent headers list.
  + Fixed borders display in cell format dialog.
  + Ask user to locate solver binaries when plain search fails.
    [bgo#619519]
  + Fix problem with solver target cell entry.
  + Fix date function docs issues. [bgo#623669]
  + Fix gtk_show_uri problem affecting win32. [bgo#623605]
  + Fix mistakes pointed out by sparse.
  + Fix win32 versioning problem. [bgo#624171]
  + Improve function doc checks.
  + Eliminate almost all remnaining GdkGC usage.
* Tue Jul 27 2010 andrea@opensuse.org
- Update to version 1.10.7:
  + Improve function syntax and formula guru tooltips.
  + Avoid superfluous redo items under validation failure.
    [bgo#622509]
  + Fix validation for array and range entry. [bgo#622511]
  + Autofit column widths in stf import. [bgo#427382]
  + Ensure the table range is unlocked before allowing the data
    table to be configured.
  + Also store any markup if entering text in several cells at
    once. [bgo#622530]
  + Read HTML files with nested tables. [bgo#594789]
  + Fixed autofilter (and other) combo positions. [bgo#621817]
  + Improve function syntax tooltips.
  + Fix excessive memory use problem with xlsx. [bgo#622365]
  + Make BackSpace work as Delete on pane. [bgo#622599]
  + Improve handling of MS-style HTML in clipboard. [bgo#617801]
- Changes from version 1.10.6:
  + Add Wilcoxon Signed Rank Test tools for one and two
    populations.
  + Fix spin button handling in various tool dialogs. [bgo#619971]
  + Redesign define-named-expressions dialog. [bgo#465840]
  + Add paste-names dialog. [bgo#613325]
  + Make changing the scope of a named expression undoable.
  + Add search tool to paste- and define-names dialogs.
    [bgo#465840]
  + Check whether defined names are in use before deleting them.
  + Add option to the regression tool to allow for multiple Y.
    [bgo#620505]
  + Ensure that names cannot be mistaken as cell references.
    [bgo#409997]
  + Add search function to function selector. [bgo#495776]
  + Add function help menu item. [bgo#156777]
  + Improve ACCRINT and its description. [bgo#611436]
  + Fix tests for homogeneity and independence for non-square
    tables. [bgo#621227]
  + Show all ranges while editing. [bgo#166653]
  + Provide a tool tip showing function syntax. [bgo#56172]
  + Provide more navigation options. [bgo#15010]
  + Check with user before hiding all rows or columns. [bgo#316976]
  + Check with user before pasting too many copies. [bgo#530956]
  + Do not ungrab a not grabbed item. [bgo#620369]
  + Always update the right series entry. [bgo#620719]
  + Fixed multi-line item edit selection. [bgo#621235]
  + Make sure windows for help commands show up on right screen.
  + Fix dependency tabulation undo issue.
  + Fix critical when inserting graph using keys.
  + Automate win32 help generation.
  + Mark a sheet dirty when its tab colour is changed. [bgo#621191]
  + Fix SERIESSUM issue.
  + Modernize code for LINEST, LOGEST, and  LOGREG. [bgo#317426]
  + GEOMDIST: avoid overflow in extreme cases.
  + SFTEST: improve extreme-case precision.
  + Fix RANDLEVY.
  + Fix hidden-sheet problem. [bgo#621463]
  + Improve help text sanity checks.
  + Fix minor parsing problem.
  + Handle missing data in FORECAST properly. [bgo#621417]
  + Handle missing data in GROWTH properly. [bgo#621418]
  + Improve BINOM.DIST.RANGE.
  + Modernize STEYX.
  + Plug evaluation leak.
  + Fix memory handling issue for dependents.
- Changes from version 1.10.5:
  + Add Wilcoxon-Mann-Whitney test tool.
  + Fix stf crash. [bgo#619283]
  + Persist solver model type.
  + Add non-linear solver. [bgo#614865]
  + Feed the gtk+ deprecation monster. [bgo#572240]
  + Fix win32/paradox problem. [bgo#619942]
  + Improve page setup dialog. [bgo#619421]
- Changes from version 1.10.4:
  + Include version number in HTML export.
  + Fixed autofill issues. [bgo#618687]
  + Linear regression test suite.
  + Fix TABLE problem. [bgo#618829]
  + Handle "Jan 2010" and "January 2010" better.
  + Fix date parsing problems for invalid years.
  + Fix sheet order dialog layout. [bgo#619056]
- Changes from version 1.10.3:
  + Fix CHITEST for rectangular ranges. [bgo#615920]
  + Fix printing and preview of graph only sheets. [bgo#616475]
  + Make even active sheets invisible. [bgo#616474]
  + Improve date and time import from and export to ODF.
    [bgo#617208]
  + Protect against accidentally pushing data off the sheet.
    [bgo#98562]
  + Make Advanced Filter (except filter-in-place) undoable.
  + Fix Data->Filter->ShowAll for Advanced Filter. [bgo#611079]
  + Remove undesired interaction between Advanced Filters and
    Autofilters.
  + Make the par argument to ACCRINT optional. [bgo#323545]
  + Improve keyboard navigation of the configurable text
    importer. [bgo#614939,bgo#614941]
  + Implement graph only sheets. [bgo#158170]
  + Fix chart title import when excel automagically uses the unique
    series label. [bgo#616262]
  + Allow multiple and block selection for graph vector data.
    [bgo#494685,bgo#616068]
  + Use the "combo-activate" signal where appropriate? [bgo#583175]
  + Make sure an empty string is shown with a quote.
  + Fix problem loading cells with empty strings. [bgo#616139]
  + Fix WEEKNUM problems. [bgo#616330]
  + Fix hidden-sheet problem. [bgo#616549]
  + Fix auto-expr problem. [bgo#575104]
  + Fix xls-save problems with custom autofilters.
  + Fix auto-filter problem. [bgo#383400]
  + Fix advanced-filter problem with multiple criteria.
    [bgo#164169]
  + Fix problem parsing complex numbers.
  + Improve error handle for complex functions.
  + Improve IMPOWER.
  + Fix sheet duplicate bugs. [Part of bgo#617469]
  + Clean-up handling of pango contexts.
  + Fix old graph problem. [bgo#142412]
- Remove gnumeric-no-disable-deprecated.patch: fixed upstream.
* Mon Jun 14 2010 sbrabec@suse.cz
- Removed incomplete translations imported by
  translation-update-upstream.
* Wed Apr 28 2010 dimstar@opensuse.org
- Update to version 1.10.2:
  + bgo#612820: Fix build with --disable-solver
  + bgo#600085: Fix column and row header display under Quartz
  + bgo#613523: Fix preferences in gconf-less situations
  + bgo#613768: Implement first letter capitalization
  + bgo#614031: Extend regression tool to perform multiple simple
    regressions
  + bgo#614746: Fix ZTEST description
  + Various ODF export fixes
  + Adjust regression tool to reflect the changes to TDIST
  + Basic import and export of text boxes from ODF files
  + bgo#615777: Watch for the null date in OOXML import
  + bgo#615365: Print pattern backgrounds
  + Improve object sizing tooltip positioning a bit.
  + bgo#611073: Fix filter critical
  + Make more menu entries available when an object is selected
  + Improve partitioning of status area
  + bgo#614147: Fix goal seek problem affecting XIRR
  + bgo#614257: Fix export xls of XIRR, FVSCHEDULE, and XNPV
  + bgo#603667: Patch gtk+ so GtkEntry widgets on win32 draw right
  + bgo#615845: Fix xls export of cell comments
  + bgo#615772: Fix error propagation problem
  + Partially clean up INDEX implementation
  + Make regression functions return a result when goffice reports
    that the problem is near singular, but still good
  + Documentation updates.
* Tue Mar  9 2010 dimstar@opensuse.org
- Update to version 1.10.1:
  + bgo#610175: Fix storing of error-literals in ODF.
  + bgo#610399: Don't export filter combos to ODF.
  + bgo#610399: Apply filter on ODF import.
  + bgo#610537: Fix display of autocomplete suggestions.
  + bgo#611633: Fix formatting of multirow cells in LaTeX export.
  + Protect exported LaTeX files from babel shorthands.
  + bgo#610012: Fix a crash in excelplugin.
  + bgo#611076: Fix cursor appearance.
  + Turn off -Wstrict-prototypes for the stable series.
  + bgo#610178: Fix ODF read problem.
  + Fix rendering problem with iterated evaluation.
  + bgo#611406: Fix solver undo problem.
  + bgo#611362: Fix graph label problem.
  + bgo#611407: Fix GLPK solver issue.
  + bgo#611842: Fix ssindex crash.
  + bgo#611824: Fix ODF export of intersection.
  + Fix cell comment critical.
* Sun Feb 14 2010 vuntz@opensuse.org
- Update to version 1.10.0:
  + Fix ODF contour/surface plot confusion. [bgo#607631]
  + Include compatibility info in the gnumeric manual.
  + Fix confidence interval in simulation output. [bgo#607970]
  + Fix TRIMMEAN border case. [bgo#607562]
  + Fix TDIST border case. [bgo#607008]
  + Fix problem with hpaned for tabs/scrollbar. [bgo#607794]
  + Support for XLL files. [bgo#597849]
- Add explicit libglade2-devel, libgsf-devel BuildRequires instead
  of relying on other devel packages to bring them.
* Wed Jan 27 2010 vuntz@opensuse.org
- Update to version 1.9.18:
  + Add paste special flip horizontally and vertically.
    [bgo#393367]
  + Add EIGEN function to calculate eigenvalues and eigenvectors of
    real symmetric matrices.
  + Add principal components analysis.
  + Load graph series labels and categories from ODF files.
    [bgo#379220]
  + Write series labels to ODF files.
  + Fix tab behaviour. [bgo#388344]
  + Print sheet widget objects. [bgo#144787]
  + Allow sheet object size and position to be specified via a
    dialog.
  + Allow the sheet object name to be specified. [bgo#596545]
  + Add menu item to select sheet objects. [bgo#338615]
  + Enable sheet tab menu when objects are selected. [bgo#604496]
  + Fix empty cell handling of the advanced filter. [bgo#599064]
  + Fix scroll bar problem with large frozen panes. [bgo#68603]
  + Singleton selections now cause the sort buttons to sort the
    whole sheet below the selection. [bgo#141313]
  + Have the formula guru auto-quote unparsable expressions.
    [bgo#442941]
  + Create default tip for hyperlinks. [bgo#316974]
  + Add GET.LINK. [bgo#128534]
  + Add "Don't change formulae" to paste special. [bgo#123326]
  + Select pasted objects. [bgo#604227]
  + Add auto expression menu items to add formula. [bgo#8872]
  + Some updates to the Gnumeric manual.
  + Fix tool tip position for recent gtk (2.18 or newer).
    [bgo#605723]
  + Fix NPV documentation. [bgo#22381]
  + Fix type errors. [bgo#606066]
  + Add surface plot description. [bgo#604285]
  + Include the short functions descriptions in the documentation.
    [bgo#606354]
  + Fix sheet handling in validation setup. [bgo#606458]
  + Allow some of the text export properties to be saved as
    default.  [bgo#559749]
  + Fix printing of repeated rows and columns. [bgo#607451]
  + Fix import export of line type in scatter plots. [bgo#605043]
  + Force sharing of first series in line plots when requested.
    [bgo#605330]
  + Fixed mouse cursor for object resizing in RTL mode.
    [bgo#605514]
  + Fix use of ExprEntry from glade on win32.
  + More win32 build fixes (xslt for libgda & poppler).
  + Fix pango test harness.
  + Fix use of Tab in ExprEntry for gurus.
  + Adapt to latest gtk-2.19.3 GSEAL.
  + Fix GCD border case. [bgo#606870]
* Fri Jan 22 2010 vuntz@opensuse.org
- Add gnumeric-no-disable-deprecated.patch to fix build with new
  GTK+: we don't need to ignore deprecated API.
- Version the Provides/Obsoletes of gnumeric2 to avoid
  self-obsoletion rpmlint warning.
* Wed Dec 16 2009 vuntz@opensuse.org
- Update to version 1.9.17:
  + Update EURO and EUROCONVERT with currencies added in 2007 to
    2009.
  + Export hyperlinks to ODF. [bgo#603533]
  + Make EUROCONVERT Excel compatible [bgo#603755]
  + Update modification times. [bgo#603099]
  + Add RANK.AVG (rank function returning average rank for ties)
  + Added Sign Test to statistical analysis tools
  + Implement --one-file-per-sheet in ssconvert [bgo#604549]
  + Fixed problem with row headers. [bgo#603862]
  + Fixed pane origin when zoomed. [bgo#604373]
  + Make the cell comment red triangle visible in RTL mode.
    [bgo#604580]
  + Elminate use of "float".
  + Fix selection problem. [bgo#601107]
  + Automate solver testing.
  + Fix SUMIF problems. [bgo#603671] [bgo#604214]
  + Fix DATEDIF problem across bogus 1900-02-29. [bgo#599461]
  + Fix graph editor crash. [bgo#604223]
  + Fix goal seek problems.
  + Fix ODS import crash. [bgo#604615]
* Thu Dec 10 2009 aj@suse.de
- Devel packages does not require libgnomeprint-devel anymore.
* Fri Dec  4 2009 vuntz@opensuse.org
- Update to version 1.9.16:
  + Clarify distinction between Document and View Properties.
  + Sort the translated labels in the preference dialog.
  + Turn view properties dialog into instant-apply dialog.
  + Temporarily remember the sort setups. [bgo#100541]
  + Work around GTK bgo#601922.
  + Add ADTEST (Anderson-Darling Test for Normality).
  + Add normality test tool.
  + Add LKSTEST (Lilliefors (Kolmogorov-Smirnov) Test of Normality).
  + Add SFTEST (Shapiro-Francia Test of Normality).
  + Add CVMTEST (Cramér-von Mises Test of Normality).
  + Fix cursor and cell edition on dark backgrounds. [bgo#600656]
  + Fix multiple error message boxes in graph guru. [bgo#152517]
  + Invert selected text in a cell when editing. [bgo#122176]
  + Allow selection when the click occur after the last character.
    [bgo#388342]
  + Fixed selecting text in a cell. [bgo#337521]
  + turnkey win32 build on 32bit host.
  + update desktop file to follow new guidelines.
  + Resurrect long-double support.
  + More solver fixes.
  + Plug another mps leak.
  + Fix problem with remote uris. [bgo#601274]
  + Use external solver program.
  + Allow constants on solver constraints' rhs. [bgo#369728]
  + Fix extreme case for R.PGAMMA.
  + Fix solver undo/redo.
  + Make solver parameter changes always persist. [bgo#440664]
  + Re-implement MPS importer.
  + Fix matching of "Sep 23 2008". [bgo#603116]
  + Major scenario code cleanup.
  + Implement load and save of scenarios.
- Changes from version 1.9.15:
  + Add RANDSNORM and RANDSTDIST. [bgo#144717]
  + Add R.PSNORM, R.DSNORM and R.DST.
  + Fix small sort dialog problem. [bgo#599091]
  + A few functions from the christian liturgical calendar.
  + Add ODF compatibility functions DAYS, ISFORMULA, IFNA, SHEETS,
    SHEET and NUMBERVALUE.
  + Work around OpenOffice.org saving function names in lowercase.
  + Add BINOM.DIST.RANGE (equivalent to the ODF function B).
  + Make Autofilter addition & removal undoable. [bgo#478152]
  + Fix autocorrection exception lists. [bgo#600055]
  + Move autocorrection setup into preferences.
  + Fix HTML export of strikethrough and subscript/superscript.
    [bgo#600163]
  + Fixed graph size issues. [bgo#599887]
  + First steps towards a turnkey win32 build.
  + Fix sheet-resize vs. merges issue. [bgo#582030]
  + Fix xls export of check boxes and radio buttons. [Part of
    bgo#597035]
  + Add xls export of spin buttons. [Part of bgo#597035]
  + Add xls export of scroll bars. [Part of bgo#597035]
  + Add xls export of list widgets. [Part of bgo#597035]
  + Add xls export of combo widgets. [Part of bgo#597035]
  + Add xls export of button widgets. [Part of bgo#597035]
  + Make it possible for arrows to have arrow heads in both ends.
  + Implement round arrow heads.
  + Fix xls import and export of line styles.
  + Save and read new arrow attributes in xml format.
  + Fix Excel-to-Gnumeric paste problem. [bgo#381732, bgo#388531].
  + Fix Alt-Enter problems. [bgo#597295]
  + Make DATE work for pre-1900 dates. [bgo#599365]
  + Add lpsolve output format.
  + Plug solver leaks.
  + Some solver cleanups.
  + Fix reading of solver constraints.
  + Hebrew Calendar functions. [bgo#153738]
- Changes from version 1.9.14:
  + Add button sheet object.
  + Add radiobutton sheet object. [bgo#595670]
  + Add more ODF elements on ODF read. [bgo#595750]
  + Fix 2-factor ANOVA with replication.
  + Fix diagonal borders in ODF export/import.
  + For freezing of panes consider edit cell A1 special.
    [bgo#594875]
  + Don't convert blank cells to 0 in LINEST. [bgo#551234]
  + Fix histogram tool.
  + Make plugins GUI labels translatable. [bgo#159806]
  + Fix more canvas issues.
  + Enable image filling in shapes.
  + Fix inter-process pasting of merged regions.
  + Make inter-process pasting use the sax parser.
  + Make auto-format templates use the sax parser.
  + Fix loading of diagonal border styles.
  + Improve consistency when moving toolbars around.
  + Fix translation problem with toolbar menu. [bgo#587250]
  + Fix printing of coloured sheet objects.
  + Fix printing of lines and arrows.
  + Fix sheet object/clipboard related critical on exit.
    [bgo#596509]
  + Fix Excel-crashing export problem with objects. [bgo#596886]
  + Add name property to sheet objects.
  + Start cleaning up xls sheet object writing.
  + Plug xls export leaks.
  + Implement export of lines and arrows to xls. [Part of
    bgo#597035]
  + Fix xls reading of sheet object colours.
  + Export line and textbox colouring and widths. [Part of
    bgo#597035]
* Mon Oct 26 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Tue Sep 29 2009 vuntz@opensuse.org
- Update to version 1.9.13:
  + Fix grab issue after dragging an object. [deb#546559]
  + Reimplement double-click in item-cursor. [deb#546690]
  + Fix access to GocWidget in sheet widgets. [bgo#595627 and
    bgo#595648]
  + Fixes text export GUI issue. [bgo#594155]
  + Fix minor status line issue. [bgo#594469]
  + Fix print crash for sheet object. [bgo#594862]
  + Limit memory usage for rendered values.
  + Fix auto-format.
  + Fix API installation problem. [bgo#595317]
  + Put zoom action on vertical toolbars too. [bgo#590889]
- Remove a wrong Provides from devel package: it provided a header
  file that is not existing anymore.
- Do not package omf files twice.
* Wed Sep  9 2009 dimstar@opensuse.org
- Update to version 1.9.12:
  + Add CHOLESKY
  + bgo#593816 - Fix ODF background colour export
  + bgo#593851 - Handle super/subscript in html export
  + bgo#594041 - Fix crash on unknown chart type
  + bgo#594041 - Handle ODF import/export of surface plots
    originally created in XL
  + bgo#594068 - Don't use simple GOData when importing xls files
  + bgo#593624 - Fix menu sensitivity problem
  + Simplify GnmColor
  + http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=544975
    Fix grab problem
  + Simplify GnmFont.
* Mon Aug 31 2009 dimstar@opensuse.org
- Update to version 1.9.11:
  + Add AVERAGEIF, MUNIT, RRI, SEARCHB, REPLACEB, COMBINA, ARABIC.
  + Improve import of ODF functions.
  + Use GocCanvas instead of FooCanvas.
  + Add GAMMA.
  + bgo#592545 - Fix Insert-Date+Time.
  + bgo#593238 - Fix problem with VLOOKUP and HLOOKUP when both are
    used on the same data range.
* Sun Aug 16 2009 dominique-obs@leuenberger.net
- Update to version 1.9.10:
  + Improve ODF export.
  + Add OpenFormula comp. descriptors to some function
    documentations.
  + Implement new functions CSC, CSCH, SEC, and SECH.
  + Implement new functions LEFTB, MIDB, RIGHTB.
  + Implement ASC and add new function JIS.
  + bgo#586672 - Fix printing crash.
  + Fix import of currency symbols from ODF.
  + Improve import of elapsed time from ODF.
  + Import some conditional cell formats from ODF.
  + bgo#587818 - Fix "not-between" conditional styles.
  + Show existence of conditional styles in format dialog.
  + Add an initialy hidden long format toolbar.
  + bgo#550933 - Fix std error for intercept in non-affine case
    of LINEST.
  + bgo#588107 - Fix loading of charts from MS generated ODF files.
  + Add some sheet object support to ODF export.
  + Export basic charts to ODF.
  + bgo#590257 - Fix format labels in configurable text importer.
  + bgo#590175 - Add warning for missing plugins needed by tools.
  + bgo#590375 - Fix percentage histogram.
  + Fix non-label 2-factor ANOVA with replication.
  + Fix various minor bugs.
  + Convert old help texts to new format.
  + bgo#588297 - Fix col/row resize.
  + bgo#586215 - Make SUMIF/COUNTIF and the D* functions
    understand pattern.
  + Make dialogs remember their sizes and positions.
  + Fix crash with new-from-template.
  + bgo#585701 - Rework loading of configuration.
  + Support evaluated examples in function docs.
  + Simplify Win32 build.
  + Convert old help texts to new format.
  + Fix problem with print area.
  + bgo#587992 - Fix problems with in-sheet combos.
  + bgo#588110 - Fix translation textdomain confusion.
  + bgo#589105 - Avoid using
    gtk_tree_view_column_get_cell_renderers.
  + bgo#588997 - Fix DEC2HEX and friends for large values.
  + Make undo/redo visible for vertical toolbar.
  + Add some checking of help texts' sanity.
- Drop gnumeric-1.9.9-bgo589105.patch, upstreamed.
* Mon Jul 27 2009 dominique-obs@leuenberger.net
- Add gnumeric-1.9.9-bgo589105.patch. Patch taken from upstream
  git, commit id=885d4f
* Mon Jun 22 2009 dominique-obs@leuenberger.net
- Update to version 1.9.9:
  + Fix scrolling via mouse wheels, bgo#533051
  + Add superscipt and subscript buttons, bgo#583327
  + New FOURIER function, Improve Fourier transform tool
  + Fix html export, bgo#586028
  + Fix array editing criticals, bgo#584746
  + Fix style problems with operator.xls, bgo#585178
  + Implement new functions COT and ACOT, bgo#585270
  + Fix GCD, bgo#585271
  + Parse x^y^z as (x^y)^z from ODF files, bgo#585277
  + Fix text import problem, bgo#135523
  + Implement new-from-template, bgo#303657
  + Implement new functions COTH and ACOTH, bgo#586170
  + Fix tsa crashes. bgo#58619, bgo#586427
  + Fix IF problems with empties and arrays, bgo#586218, bgo#586312
  + GOString start of richtext and phonetic support.
* Sun May 24 2009 vuntz@novell.com
- Update to version 1.9.8:
  + Save and load text formatting of comments and of sheet object
    labels [bgo#580979, bgo#580838]
  + Lots of improvements to the ODF exporter [bgo#581937,
    bgo#553508, bgo#582903]
  + Some improvements to the ODF importer [bgo#581953]
  + Some improvements to the xlsx exporter [bgo#569862, bgo#581896]
  + Write some character based formats to HTML files. [bgo#582118]
  + Closer to a turnkey win32 build.
  + Optimize styles on load.
  + Prune fn-lookup caches in case someone is being silly.
  + Plug leak in HTML paste.
  + Respect the sheet size prefs for new blank workbooks.
  + Cache large ranges, possibly sorted.
  + Add progress display for OO import.
  + Improve ssindex' coverage.
  + Make it possible to have horizontal widgets too. [bgo#166487]
  + Fix sheet-object paste crash. [bgo#490479]
  + Fix critical in format dialog. [bgo#582890]
  + Turn WorkbookView into a more proper GObject.
  + Hide scrollbars as requested. [bgo#583005]
  + Fix date conventions in graphs.
  + Improve GUI for date/time axes. [bgo#574681]
  + Fix R1C1 issues.
  + Extend ssconvert to also merge multiple sheets. [bgo#581616]
* Thu May  7 2009 vuntz@novell.com
- Update to version 1.9.7:
  + Fix some divergence between character weight in the label
    properties dialog and the label itself.
  + Add interface to format cell comments
  + Fix printing of sheet objects whose text intersects with
    markup. [bgo#581125]
  + Load meta data from gnumeric files [bgo#578607]
  + Do not crash in rendr_value for NULL values. [bgo#581120]
  + XLSX start reading external refs.
  + XL2003-XML enable the use of builtin formats, and drop '.sml'
    kludge.
  + Add pref entry to set default value of autosave.
  + Fix xls save problem with sheets that are too big for the
    format.
  + Fix global-name .gnumeric warning. [bgo#580227]
  + Fix tooltip positioning. [bgo#580358]
  + Fix xlst export problem. [bgo#580360]
  + Fix size of sheets loaded from Applix files.
  + Fix problem with global names shadowed by sheet names.
    [bgo#306686]
  + Fix relocation problem with expressions using names.
    [bgo#552749]
  + Fix fullscreen toolbar issues. [bgo#574603]
  + Fix various R1C1 bugs.
  + Fix precision for xml saving inside graphs.
  + Fix long-sheet-name GUI issue. [bgo#580837]
  + Fix dependency problem with names. [bgo#581117]
  + Fix style-allocation screwup.
  + Fix xls export performance problem. [bgo#581378]
  + Fix xls export issue that made files readable by Gnumeric only.
  + Fix autofill crash. [bgo#581589]
  + Fix gnumeric crash exporting polygons. [bgo#581394]
- Drop gnumeric-xls-gnumeric-only.patch: fixed upstream.
* Wed May  6 2009 vuntz@novell.com
- Add gnumeric-xls-gnumeric-only.patch to fix an issue where xls
  files saved by gnumeric were readable by gnumeric only.
* Mon Apr 27 2009 vuntz@novell.com
- Update to version 1.9.6:
  + Show sheet sizes in manage sheet dialog
  + Write metadata from the property dialog to the files
  + Complete the list sheet object configuration dialog
    [bgo#578557]
  + Make all sheet object configurations undoable [bgo#114098]
  + Quieten GTK warning [bgo#579152]
  + Print text in sheet object label [bgo#144787]
  + Implement editing of a sheet object label
  + Include "italic", "strikethrough" and "bold" buttons in the
    properties dialog for sheet object labels
  + Variable sheet sizes.
  + Fixed libspredsheet.pc. [bgo#575390]
  + Improve xml probing for 2003-spreadsheetml.
  + More 2003-spreadsheetml formats.
  + New calendar template
  + Handle elapsed time formats better on text export.
  + Plug leak.
  + Fix mps loading crash. [bgo#577138]
  + Improve XIRR a bit.
  + Fix Applix loading crash. [bgo#577145]
  + Fix Lotus loading crash. [bgo#577156]
  + Fix XLS loading crashes. [bgo#577205, bgo#577208, bgo#577259,
    bgo#577260, bgo#577348, bgo#577351, bgo#577399, bgo#577400,
    bgo#577503, bgo#577504]
  + Add sorted sheet list to tab menu.
  + Fix criticals during Lotus load.
  + Clean up Sheet object.
  + Clean up str.h usage.
  + Load csv and txt files into sheets as big as needed. [Part of
    bgo#168875]
  + Implement sheet resize.
  + Fix validation problem. [bgo#580157]
  + Move to libgda4.
- Change libgnomedb3-devel BuildRequires to libgnomedb-devel to use
  libgda4.
* Mon Mar 23 2009 vuntz@novell.com
- Update to version 1.9.5:
  + Fix style critical on latex export [bgo#574125]
  + Always print the whole printarea even if it has no content or
    style. [bgo#554116] [bgo#572818]
  + Fix translation of argument names for empty names.
  + Don't switch sheets when widgets are adjusted. [bgo#574734]
  + Fix printing of rotated text (negative angles or non-default
    alignment). [bgo#574813]
  + Remove crash potential for various dialogs with multiple views.
    [bgo#364291]
  + Fix some strings. [bgo#575360]
  + Make gconf use independent from the with-gnome option.
    [bgo#574813]
  + Fixed  null pointer crash inoo_plot_area(). [bgo#575403]
  + Work around semantic changes in gtk-2.16.
  + rename sr@Latn -> sr@latin
  + Fix multihead issues with cell comments.
  + Fix multihead issue with sheet reordering.
  + Fix multihead issues with tooltips.
  + Fix PFACTOR to handle huge factors.
  + Fix problem with dialogs not showing up in fullscreen mode.
    [bgo#574602]
  + Fix desktop file to always specify that we take URIs.
  + Fix sheet-ordering by dragging.  [bgo#574763]
  + Fix potential crash for cell comment dialog with multiple
    views.  [Part of #364291]
  + Fix lotus importer crash.  [bgo#575190]
  + Improve entry of date for locales not using slashes.
    [Part of bgo#33229]
  + Make date edit use the date separator of the locale.
    [Part of bgo#33229]
  + Fix xls writing crash.  [Part of #575318]
  + Fix criticals in xls export for comments without author.
  + Fix crash while loading broken xls.  [bgo#575393]
  + Fix string problem with broken xls.  [bgo#575452]
  + Improve date entry for locales that end abbreviated month names
    with punctuation.
  + Fix ODS crashes.  [bgo#575600] [bgo#575843] [bgo#575981]
  + Use goffice magic formats for certain date and time formats so
    we can persist them in .gnumeric.
  + Fix setting of radio button objects' text.
  + Implement OOO probing.  [bgo#574381]
- Stop using --with-gnome: it's now possible to use gconf without
  this. Also remove libgnomeui-devel BuildRequires.
- Add gconf2-devel BuildRequires.
- Remove sr@latin hack: fixed upstream.
- Drop gnumeric-doc.patch: not needed anymore.
- Add back -fno-strict-aliasing to CFLAGS. There's a warning about
  it.
* Tue Mar 10 2009 vuntz@novell.com
- Use --with-gnome because we really want gnumeric to use gconf.
- Add libgnomeui-devel BuildRequires.
* Fri Feb 27 2009 vuntz@novell.com
- Update to version 1.9.4:
  + Many changes. See NEWS for the complete details. The following
    changes are worth mentioning:
  - Work around vulnerability in Python. [bgo#569648]
  - Make non-gnome the default. [bgo#558840]
- Remove BuildRequires: docbook-utils, gnutls-devel,
  gtksourceview18-devel, indent, libgnomeprintui-devel, libidl,
  libtiff-devel, libwnck-devel, pcre-devel, perl-XML-Parser,
  python-gtk-devel.
- Change BuildRequires: libgnomedb-devel to libgnomedb3-devel.
- Add BuildRequires: python-gobject2-devel.
- Remove unneeded calls to autoreconf and intltoolize.
- Remove -fno-strict-aliasing from CFLAGS.
- Pass --disable-static to configure.
- Use makeinstall.
- Clean removal of .la files.
* Sat Jan 31 2009 vuntz@novell.com
- Use sr@latin instead of sr@Latn.
* Fri Oct 24 2008 maw@suse.de
- Update to version 1.9.3:
  + Many changes and fixes; see the file NEWS for a full account.
* Thu Sep  4 2008 mboman@novell.com
- Update to version 1.9.2
  + To many fixes and changes to list. Please see NEWS for full details.
- Removed gnumeric-autobuild-error.patch. Fixed upstream.
* Wed Apr 30 2008 vuntz@suse.de
- Stop recommending agfa-fonts, after quick discussion on the
  mailing list. Let's stay with free fonts if possible :-)
* Tue Apr 29 2008 vuntz@suse.de
- Drop gnumeric-pro-fonts.patch. We don't depend on agfa-fonts
  anymore, so we can't use them as a default.
* Thu Apr 24 2008 maw@suse.de
- Only recommend agfa-fonts; additionally Recommend
  liberation-fonts and ghostscript-fonts-std
- Clean up the -devel subpackage's requires.
* Wed Apr  2 2008 sbrabec@suse.cz
- Updated to version 1.8.2:
  * many bug fixes
  * memory leak fixes
  * several new features, see NEWS for details
* Thu Mar  6 2008 maw@suse.de
- Fix the build when against newer versions of intltool.
* Wed Nov  7 2007 mauro@suse.de
- Fixed gcc 4.3 issues for beta.
* Thu Oct 11 2007 sbrabec@suse.cz
- Removed bogus dependency on mDNSResponder.
* Tue Aug  7 2007 maw@suse.de
- Use %%fdupes
- Split off a -lang subpackage
- s#%%run_ldconfig#/sbin/ldconfig/ in %%post and %%postun.
* Fri Aug  3 2007 jpr@suse.de
- Update to 1.7.11
- Save and restore default paper, margins and various other print
  settings
- Handle differences in page setup between sheets when printing
  multiple sheets
- Fix handling of "print even if only style". (BGO #438743)
- Implement printing of row and column headers
- Fix saving of null header/footer items (BGO #449836)
- Fix TINV for large degree of freedom
- Fix check for long double support in goffice.
- Import legend and axis labels fonts from excel in charts. (BGO #437858)
- Fix performance issues in float_range_function2 and fn-tsa plugin.
- Fix drawing of large cursor while sheet scrolls. (BGO #444610)
- Fix drawing of merged cells in RTL. (BGO #442463), [442467)
- Fix editing in RTL, and for merged cells.
- Properties to store fine tuned capabilities in protected sheets.
- Read/Write of protected sheet capabilities for XLS/XLSX.
- Move the OpenPkg support code into libgsf from our xlsx plugin.
- Fix placement of validation combo in merged cells.
- Eval validation functions as arrays.
- Make Morten's pdf exporter available from gnumeric too.
- Start to implement limits to selection in protected sheets.
- Handle array expressions in SYLK importer.
- ODF import/export for hidden and RTL sheets.
- Fix redraw of spanning cells when toggling RTL.
- Work around ODF's lack of a default col/row style.
- Fix crash in t-test. (BGO #450676).
- Sylk import support for arrays, and encoding.
- Sylk export.
- Configurability for which direction <Enter> moves.
- Calc property import/export for xlsx.
- Update validation combo moving between identical styles. (BGO #453525)
- Patch the problems found by coverity.
- Fix win32 docs. (BGO #443726)
- Be more flexible about range relocation for ins/del cells. (BGO #439347)
- Make ssconvert able to export to pdf.  (BGO #381965)
- Fix loading of tab text colour.  (BGO #437743)
- Improve handling of foreign recently-used files.  (BGO #438918)
- Improve save-on-exit dialog.
- Fix potentially confusing save-in-wrong-format-on-exit bug.
- Tentatively fix issue with recent Pango.  (BGO #440514)
- Provide good mime type for recent documents.
- Fix localized-format problem in cell format dialog.  (BGO #442657)
- Fix R1C1 problem.  (BGO #443832)
- Fix performance problem when selecting large areas.  (BGO #445617)
- Fix loading/saving of R1C1 attribute.  (BGO #448714)
- Fix overflow problem when int!=long.  (BGO #458158)
- Fix the inline documentation for python addins. (BGO #412804)
- Reimplement scaling
- Save orientation
- Show paper preview
- Show unit selector in print dialog
- Add margin adjustments
- New Time Series Analysis plugin.
- Fix inadvertent relocation of reference on other sheets. (BGO #433907)
- Remove upstreamed patches
- Use %%suse_update_desktop_file instead of a patch
- Fix categories (#258281)
- goffice plugin is no longer built by upstream
* Tue Jul 10 2007 maw@suse.de
- Update to version 1.7.9, which:
- Switches from gtk print to gnome print
- Imports and exports inline arrays in ODF
- Exports cell comments to xls
- Fixes the following bugs against bugzilla.gnome.org: #415007,
  [#414815], #308562, #417632, #115112, #67453], #418868, #423603,
  [#421678], #427019, and #152584.
* Thu Jun  7 2007 sbrabec@suse.cz
- Fixed deskop file translation.
- Fixed devel dependencies.
- Removed invalid desktop Category "Application" (#254654).
* Thu May 24 2007 ro@suse.de
- branch off devel package
* Tue Mar  6 2007 jhargadon@suse.de
- update to version 1.7.6
- Implement sax import of sheet objects.
- Implement List and Combo objects.
- XLSX support for import and export of autofilters
- Improve number formatting
- Put the style feedback onto an idle handle to improve cursor
  responsiveness.
- Improve autofill/validation combos.
- Add automatic test framework
- Rewrite expression relocation logic.
- Add accelerator (Alt-=) for auto-sum.
- Make paytype handler more flexible.
- Add accelerator for group/ungroup and inc/dec indent
- Make clipboard faster
- Add more conditional format types
- New look for col/row headers
- many bug fixes
* Wed Jan 17 2007 sbrabec@suse.cz
- Removed obsolete scrollkeeper directory (#230786).
* Thu Jan  4 2007 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Sat Nov 18 2006 stbinner@suse.de
- fix Name entry of .desktop file (remove GenericName dupe part)
* Fri Oct 27 2006 jhargadon@suse.de
- added a symlink for the help files in the specfile for bug
  [#142827]
* Wed Sep 27 2006 jhargadon@suse.de
- update to version 1.6.3
- Fix exporting of scaled axes. [#332012]
- Backport duping sheet props when sheet is duped
- Adding an autofilter dirties the sheet
- Fix xls import of pie outlines
- Implement xml and xls saving/loading of "protected" attribute
- many bug fixes
* Thu Aug 31 2006 gekker@suse.de
- Remove unnecessary gal2-devel from BuildRequires
* Wed Aug 16 2006 cthiel@suse.de
- buildrequire python-gtk-devel instead of python-gtk
* Wed Aug 16 2006 ro@suse.de
- added python-gobject2-devel to BuildRequires
* Sun Feb  5 2006 jpr@suse.de
- run ldconfig in post/postun for libspreadsheet
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Dec 20 2005 ro@suse.de
- get translations for gnumeric-functions as well
* Wed Nov 16 2005 sbrabec@suse.cz
- Updated to version 1.6.1.
* Fri Nov  4 2005 sbrabec@suse.cz
- Updated to version 1.6.0.
* Mon Sep 12 2005 gekker@suse.de
- Patch version 1.4.3 to work with libgsf-1.12.1 (116579)
- This patch supercedes the fix-build patch
* Sun Aug  7 2005 adrian@suse.de
- fix build
* Thu Jul  7 2005 schwab@suse.de
- Fix #nfb.
- Fix uninitialized variable.
* Mon Mar 14 2005 jody@suse.de
- upstream 1.4.3
- enable ssindex
* Thu Feb 17 2005 ke@suse.de
- Fix gnumeric.xml and included files; [# 50960].
- Provide a link to /opt/gnome/share/gnumeric/1.4.2/doc to make the
  documentation files visible to the help system (yelp) - probably
  superfluous; [# 50960].
* Tue Feb  1 2005 sbrabec@suse.cz
- Fixed packlist path.
* Mon Jan 31 2005 sbrabec@suse.cz
- Fixed missing declaration.
- Fixed perl support detection.
* Thu Jan 20 2005 sbrabec@suse.cz
- Updated to version 1.4.2.
* Wed Dec 15 2004 hvogel@suse.de
- fix desktop file
- there is nothing in libexecdir so dont package it
* Tue Dec 14 2004 jody@suse.de
- Add scrollkeeper as a build req and handle the fallout
* Fri Dec 10 2004 jody@suse.de
- Updated to 1.4.1
- Include ssindex for beagle
- rich text
- xls chart export
- more accuracy
- full array expression support
* Wed Nov 24 2004 ro@suse.de
- make specfile rpm-3 compliant (quote non-numeric if arguments)
* Tue Nov  2 2004 ro@suse.de
- locale rename: no -> nb
* Tue Oct 12 2004 sbrabec@suse.cz
- Fixed libexecdir for bi-arch (#47050).
* Tue Sep  7 2004 sbrabec@suse.cz
- Generated shared mime info.
* Fri Jun 25 2004 jody@suse.de
- Updated to 1.2.13
* Fri May  7 2004 clahey@suse.de
- Updated to version 1.2.12.
- Added patch gnumeric-pro-fonts.patch.
* Thu Mar 18 2004 sbrabec@suse.cz
- Updated to version 1.2.8 (#36348, #32861).
* Mon Mar 15 2004 sbrabec@suse.cz
- FHS 2.3 fix (mandir, infodir, #35821).
* Wed Mar 10 2004 sbrabec@suse.cz
- Fixed gconf schemas installation (#33114).
- Fixed %%doc attributes (#33163).
- Use %%find_lang.
* Mon Mar  8 2004 hhetter@suse.de
- use gdk-pixbuf-query-loaders-64 on 64bit architectures
* Fri Feb 20 2004 sbrabec@suse.cz
- Package renamed to gnumeric.
* Thu Feb 12 2004 hhetter@suse.de
- gconf schema (de-)installation in %%post and %%postun
* Wed Feb 11 2004 hhetter@suse.de
- updated to version 1.2.6
* Tue Jan 20 2004 hhetter@suse.de
- updated to version 1.2.5
* Tue Oct 28 2003 ro@suse.de
- added gtksourceview to neededforbuild
* Mon Oct 27 2003 sbrabec@suse.cz
- Updated to version 1.2.1.
- Do not obsolete Guppi.
* Thu Oct 16 2003 ro@suse.de
- re-enable python stuff on x86_64 and ppc64 (seems fixed)
* Wed Oct 15 2003 ro@suse.de
- fix "file listed twice"
* Mon Sep 22 2003 sbrabec@suse.cz
- Obsolete guppi1.
* Tue Sep 16 2003 sbrabec@suse.cz
- Provide and obsolete gnumeric (bug #30989).
* Thu Sep  4 2003 ro@suse.de
- python stuff can't build on lib64 (strange enough that linking
  a plugin with static libpython works elsewhere ...)
  so remove these files from filelist on x86_64 and ppc64
* Tue Aug 26 2003 sbrabec@suse.cz
- Re-enabled python support.
* Tue Aug 26 2003 ro@suse.de
- update filelist
* Mon Aug 25 2003 sbrabec@suse.cz
- Updated to version 1.1.20.
* Mon Aug 18 2003 sbrabec@suse.cz
- Use libgda instead of libgda2 (package was renamed).
* Thu Aug  7 2003 sbrabec@suse.cz
- Not use globbing for schemas in %%files.
* Tue Jul 29 2003 hhetter@suse.de
- disable python support
* Thu Jul 24 2003 hhetter@suse.de
- build with libtiff
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Tue Jul  1 2003 ro@suse.de
- updated filelist
- added directories
* Mon Jun  9 2003 sbrabec@suse.cz
- Updated to version 1.1.19.
* Wed Jun  4 2003 sbrabec@suse.cz
- Initial SuSE version of GNOME2 port.
